(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   2733561,      67309]
NotebookOptionsPosition[   2714129,      66964]
NotebookOutlinePosition[   2714494,      66980]
CellTagsIndexPosition[   2714451,      66977]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Notebook file with all certificates for the statements in the paper 
\[OpenCurlyDoubleQuote]Algebraic proof methods for identities of matrices and \
operators: improvements of Hartwig\[CloseCurlyQuote]s triple reverse order \
law\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.793702978436185*^9, 3.793703005337625*^9}, {
  3.7953446252015657`*^9, 3.7953446279236507`*^9}, {3.795848716623102*^9, 
  3.795848724797421*^9}},ExpressionUUID->"19bfce8d-5d1a-4675-bcd1-\
549558972b6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"First", ",", " ", 
    RowBox[{
    "define", " ", "a", " ", "function", " ", "to", " ", "check", " ", "the", 
     " ", "certificates"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"To", " ", "this", " ", "end"}], ",", " ", 
    RowBox[{
    "we", " ", "define", " ", "our", " ", "own", " ", "noncommutative", " ", 
     "multiplication", " ", "with", " ", "some", " ", "basic", " ", 
     "properties"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"CoeffQ", "[", "_Rational", "]"}], ":=", "True"}], "\n", 
   RowBox[{
    RowBox[{"CoeffQ", "[", "_Integer", "]"}], ":=", "True"}], "\n", 
   RowBox[{
    RowBox[{"CoeffQ", "[", "_", "]"}], ":=", "False"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Prod", "[", 
     RowBox[{"a___", ",", "0", ",", "b___"}], "]"}], "=", "0"}], "\n", 
   RowBox[{
    RowBox[{"Prod", "[", 
     RowBox[{"a___", ",", 
      RowBox[{"Prod", "[", "b___", "]"}], ",", "c___"}], "]"}], ":=", 
    RowBox[{"Prod", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Prod", "[", 
     RowBox[{"a___", ",", "b_Plus", ",", "c___"}], "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Prod", "[", 
        RowBox[{"a", ",", "#", ",", "c"}], "]"}], "&"}], "/@", "b"}], ")"}]}],
    "\n", 
   RowBox[{
    RowBox[{"Prod", "[", 
     RowBox[{"a___", ",", 
      RowBox[{"c_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CoeffQ", "[", "#", "]"}], "&"}], ")"}]}], ",", "b___"}], 
     "]"}], ":=", 
    RowBox[{"c", " ", 
     RowBox[{"Prod", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{"Prod", "[", 
     RowBox[{"a___", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d_", "?", "CoeffQ"}], ")"}], "*", "b_"}], ",", "c___"}], 
     "]"}], ":=", 
    RowBox[{"d", " ", 
     RowBox[{"Prod", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{"Prod", "[", 
     RowBox[{"a___", ",", "b_List", ",", "c___"}], "]"}], ":=", 
    RowBox[{"Prod", "[", 
     RowBox[{"a", ",", 
      RowBox[{"Sequence", "@@", "b"}], ",", "c"}], "]"}]}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "We", " ", "also", " ", "define", " ", "an", " ", "adjoint", " ", 
     "operation", " ", "with", " ", "some", " ", "basic", " ", "properties"}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"adj", "[", 
     RowBox[{"adj", "[", "a__", "]"}], "]"}], " ", ":=", " ", "a"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"adj", "[", 
     RowBox[{"NonCommutativeMultiply", "[", 
      RowBox[{"a_", ",", "b_"}], "]"}], "]"}], " ", ":=", " ", 
    RowBox[{"NonCommutativeMultiply", "[", 
     RowBox[{
      RowBox[{"adj", "[", "b", "]"}], ",", 
      RowBox[{"adj", "[", "a", "]"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"adj", "[", 
     RowBox[{"-", "a_"}], "]"}], ":=", " ", 
    RowBox[{"-", 
     RowBox[{"adj", "[", "a", "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{"adj", "[", 
     RowBox[{"Times", "[", 
      RowBox[{
       RowBox[{"a_", "?", "CoeffQ"}], ",", 
       RowBox[{"NonCommutativeMultiply", "[", "b___", "]"}]}], "]"}], "]"}], ":=",
     " ", 
    RowBox[{"a", " ", 
     RowBox[{"adj", "[", 
      RowBox[{"NonCommutativeMultiply", "[", "b", "]"}], "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{"adj", "[", 
     RowBox[{"Times", "[", 
      RowBox[{
       RowBox[{"a_", "?", "CoeffQ"}], ",", "b_"}], "]"}], "]"}], ":=", 
    RowBox[{"a", " ", 
     RowBox[{"adj", "[", "b", "]"}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Functions", " ", "to", " ", "convert", " ", "between", " ", 
     RowBox[{"Mathematica", "'"}], "s", " ", "noncommutative", " ", 
     "multiplication", " ", "and", " ", "our", " ", "data", " ", 
     "structure"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ToProd", "[", "f_", "]"}], ":=", " ", 
    RowBox[{"Expand", "[", 
     RowBox[{"Prod", "[", 
      RowBox[{"(", 
       RowBox[{"f", "//.", 
        RowBox[{"NonCommutativeMultiply", "->", "Prod"}]}], ")"}], "]"}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ToNonCommutativeMultiply", "[", "f_", "]"}], ":=", " ", 
    RowBox[{"f", "//.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Prod", "[", "]"}], "->", "1"}], ",", " ", 
       RowBox[{
        RowBox[{"Prod", "[", "a_", "]"}], "->", 
        RowBox[{"Times", "[", "a", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"Prod", "[", 
         RowBox[{"a_", ",", "b__"}], "]"}], "->", 
        RowBox[{"NonCommutativeMultiply", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}]}], "}"}]}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Auxiliary", " ", "functions"}], " ", "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Multiply", " ", "out", " ", "a", " ", "given", " ", "certificate"}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MultiplyOut", "[", "certificate_", "]"}], ":=", 
    RowBox[{"Expand", "[", 
     RowBox[{"ToNonCommutativeMultiply", "[", 
      RowBox[{"Total", "[", 
       RowBox[{"Map", "[", 
        RowBox[{"ToProd", ",", "certificate"}], "]"}], "]"}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Check", " ", "whether", " ", "a", " ", "given", " ", "certificate", " ", 
     "is", " ", 
     RowBox[{"w", ".", "r", ".", "t", ".", " ", "given"}], " ", 
     "assumptions"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LinearCombinationQ", "[", 
     RowBox[{"certificate_", ",", " ", "assumptions_"}], "]"}], " ", ":=", 
    " ", 
    RowBox[{"AllTrue", "[", 
     RowBox[{
      RowBox[{"certificate", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{"assumptions", ",", "#"}], "]"}], "&"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Check", " ", "whether", " ", "a", " ", "given", " ", "certificate", " ", 
     "only", " ", "contains", " ", "integer", " ", "coefficients"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"IntegerCoeffQ", "[", "certificate_", "]"}], ":=", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "terms", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"terms", " ", "=", 
         RowBox[{"Flatten", "[", " ", 
          RowBox[{
           RowBox[{"Map", "[", 
            RowBox[{"ToProd", ",", 
             RowBox[{"Flatten", "[", "certificate", "]"}]}], "]"}], "/.", 
           RowBox[{"Plus", "\[Rule]", "List"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"And", " ", "@@", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"MatchQ", "[", 
            RowBox[{
             RowBox[{"Prod", "[", "___", "]"}], " ", "|", " ", 
             RowBox[{"_Integer", " ", "*", " ", 
              RowBox[{"Prod", "[", "___", "]"}]}]}], "]"}], "/@", "terms"}], 
          ")"}]}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Check", " ", "that", " ", "a", " ", "single", " ", "certificate", " ", 
      "indeed", " ", "gives", " ", "a", " ", "given", " ", "claim"}], ",", 
     " ", 
     RowBox[{"is", " ", 
      RowBox[{"w", ".", "r", ".", "t", ".", " ", "to"}], " ", "the", " ", 
      "assumptions", " ", "and", " ", "that", " ", "it", " ", "only", " ", 
      "contains", " ", "integer", " ", "coefficients"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CheckCertificate", "[", 
     RowBox[{"certificate_", ",", "claim_", ",", " ", "assumptions_"}], "]"}],
     ":=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"MultiplyOut", "[", "certificate", "]"}], " ", "===", " ", 
       "claim"}], ")"}], " ", "&&", " ", 
     RowBox[{"LinearCombinationQ", "[", 
      RowBox[{"certificate", ",", "assumptions"}], "]"}], "&&", " ", 
     RowBox[{"IntegerCoeffQ", "[", "certificate", "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Check", " ", "several", " ", "certificates", " ", "at", " ", "once"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CheckCertificates", "[", 
     RowBox[{"certificates_", ",", "claims_", ",", "assumptions_"}], "]"}], ":=", 
    RowBox[{"MapThread", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"CheckCertificate", "[", 
        RowBox[{"#1", ",", "#2", ",", "assumptions"}], "]"}], "&"}], ",", 
      RowBox[{"{", 
       RowBox[{"certificates", ",", "claims"}], "}"}]}], "]"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.795848737265284*^9, 3.795848859133855*^9}, 
   3.795848895274496*^9, {3.795848940922399*^9, 3.795849002467194*^9}, {
   3.7958490413478403`*^9, 3.795849055806321*^9}, {3.795849122476326*^9, 
   3.795849269563849*^9}, {3.795849385567836*^9, 3.795849444988216*^9}, {
   3.795849497369451*^9, 3.795849603765758*^9}, {3.7958496489963083`*^9, 
   3.795849663098918*^9}, {3.7958497218997593`*^9, 3.7958497317587757`*^9}, {
   3.795850281484803*^9, 3.795850290399856*^9}, {3.795851104341419*^9, 
   3.795851192954727*^9}, {3.7958512502618837`*^9, 3.795851277870376*^9}, {
   3.795851325586195*^9, 3.7958513928605003`*^9}, {3.795851503995689*^9, 
   3.795851509848913*^9}, {3.795852608394211*^9, 3.795852638157366*^9}, {
   3.795852736724247*^9, 3.795852762342245*^9}, {3.795852952107345*^9, 
   3.7958530236685743`*^9}, {3.795853073490262*^9, 3.795853074334051*^9}, {
   3.795853122890951*^9, 3.795853132707775*^9}, {3.795854330242157*^9, 
   3.7958543641447144`*^9}, {3.795855479386602*^9, 3.7958554993477907`*^9}, {
   3.795858013452063*^9, 3.795858036996798*^9}, {3.7958580913126993`*^9, 
   3.7958580924887047`*^9}, {3.795858154422495*^9, 3.795858176163392*^9}, {
   3.795859112718398*^9, 3.7958591161516743`*^9}, {3.7958679094902678`*^9, 
   3.795867925637658*^9}, {3.7958683854377327`*^9, 3.795868419707654*^9}, {
   3.795874527942074*^9, 
   3.795874566325688*^9}},ExpressionUUID->"0fff3040-e0ab-44c0-90a8-\
d7cd47c0acd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "some", " ", "variables", " ", "that", " ", "appear", " ", 
    "in", " ", "the", " ", "certificates"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p", " ", "=", " ", 
     RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", " ", "=", " ", 
     RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m", " ", "=", " ", 
     RowBox[{"a", "**", "b", "**", "c"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "1"], " ", "=", " ", 
     RowBox[{"b", "**", "c", "**", 
      RowBox[{"adj", "[", "c", "]"}], "**", 
      RowBox[{"adj", "[", "b", "]"}], "**", 
      RowBox[{"adj", "[", "a", "]"}], "**", 
      RowBox[{"adj", "[", "aa", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "2"], " ", "=", " ", 
     RowBox[{
      RowBox[{"adj", "[", "bb", "]"}], "**", 
      RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa", "**",
       "a"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"adj", "[", "b", "]"}], "**", 
      RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**", 
      "cc"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "2"], " ", "=", " ", 
     RowBox[{"bb", "**", "aa", "**", 
      RowBox[{"adj", "[", "aa", "]"}], "**", 
      RowBox[{"adj", "[", "bb", "]"}], "**", 
      RowBox[{"adj", "[", "cc", "]"}], "**", 
      RowBox[{"adj", "[", "c", "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7958503256745167`*^9, 3.795850358147221*^9}, 
   3.795850907983965*^9, {3.795868428739088*^9, 
   3.795868428889399*^9}},ExpressionUUID->"c7743e31-7f95-464d-a4a6-\
a03fddca5283"],

Cell[CellGroupData[{

Cell["Theorem 2.1 (Hartwig original version)", "Section",
 CellChangeTimes->{{3.7731274281513777`*^9, 3.77312743009344*^9}, 
   3.7731335748586884`*^9, {3.775672302091146*^9, 3.775672305285179*^9}, {
   3.78256127668699*^9, 3.782561277751964*^9}, {3.78371141920049*^9, 
   3.783711460213315*^9}, {3.783830061641358*^9, 3.783830062505756*^9}, {
   3.792591916117496*^9, 3.792591920701108*^9}, {3.794732520769096*^9, 
   3.7947325285354548`*^9}},ExpressionUUID->"c53124fd-2698-4e18-93b7-\
5335e65534bf"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", ",", "B", ",", "C"}], TraditionalForm]],ExpressionUUID->
  "a8b2ff84-3160-4393-84b8-488e441884d1"],
 " with Moore-Penrose inverses ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "\[Dagger]"], ",", 
    SuperscriptBox["B", "\[Dagger]"], ",", 
    SuperscriptBox["C", "\[Dagger]"]}], TraditionalForm]],ExpressionUUID->
  "55c421eb-d1aa-4511-9150-4d7d4057e3ca"],
 " be such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "=", 
    RowBox[{"A", " ", "B", " ", "C"}]}], TraditionalForm]],ExpressionUUID->
  "44bdbfb7-77b8-4616-9658-f80fc1e9b62e"],
 " is defined. Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    RowBox[{
     SuperscriptBox["A", "\[Dagger]"], "A", " ", "B", " ", "C", " ", 
     SuperscriptBox["C", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "412804cd-fe5c-415e-a4d1-fea6a1dffb25"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", 
    RowBox[{"C", " ", 
     SuperscriptBox["C", "\[Dagger]"], 
     SuperscriptBox["B", "\[Dagger]"], 
     SuperscriptBox["A", "\[Dagger]"], " ", "A"}]}], TraditionalForm]],
  ExpressionUUID->"7f4251b8-92d7-4be7-b0b4-4df81010349e"],
 ". Then, the following are equivalent:\ni) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["M", "\[Dagger]"], "=", 
    RowBox[{
     SuperscriptBox["C", "\[Dagger]"], 
     SuperscriptBox["B", "\[Dagger]"], 
     SuperscriptBox["A", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "f398a091-11a7-453a-a596-49665f97fb25"],
 ";\nii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", " ", "\[Element]", " ", 
    RowBox[{"P", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}]}], TraditionalForm]],ExpressionUUID->
  "6d363c5c-fe6c-4cb4-bcf8-af06341f17c9"],
 " and both of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "*"], "A", " ", "P", " ", "Q"}], TraditionalForm]],
  ExpressionUUID->"acc8c284-ad3b-4409-81a5-4fc2b0098f91"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", " ", "P", " ", "C", " ", 
    SuperscriptBox["C", "*"]}], TraditionalForm]],ExpressionUUID->
  "4a8018ee-5e23-4985-89c7-4e83eee96aa0"],
 " are Hermitian;\niii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", " ", "\[Element]", " ", 
    RowBox[{"P", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}]}], TraditionalForm]],ExpressionUUID->
  "b4de0d70-1807-4438-a3b6-8699919872a5"],
 " and both of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "*"], "A", " ", "P", " ", "Q"}], TraditionalForm]],
  ExpressionUUID->"cf62974a-01b9-4332-bcd3-4182cca4f218"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", " ", "P", " ", "C", " ", 
    SuperscriptBox["C", "*"]}], TraditionalForm]],ExpressionUUID->
  "71180439-05ef-42c7-876c-7bdbab3ccd9b"],
 " are EP;\niv) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", " ", "\[Element]", " ", 
    RowBox[{"P", 
     RowBox[{"{", "1", "}"}]}]}], TraditionalForm]],ExpressionUUID->
  "10498bb5-f9d3-4d8f-a803-7aab0c06926c"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "=", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "70df2f6c-6dbd-4404-a4f7-70a2e6e31758"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "=", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "31b680f3-3d8e-4a6b-964a-515dae1cd2d1"],
 ";\nv) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", " ", "Q"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"P", " ", "Q"}], ")"}], "2"]}], TraditionalForm]],
  ExpressionUUID->"bc08ee59-1e93-47ba-a9d5-b9029752080b"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "=", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "761c62e4-8fbf-450d-9957-b9215f353fea"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "=", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "370a1ac4-951b-4515-a127-0a19ba92c00c"],
 ";"
}], "Text",
 CellChangeTimes->{
  3.782560019710051*^9, {3.79355874330972*^9, 3.793558826364978*^9}, {
   3.793560469747985*^9, 3.7935605933299713`*^9}, {3.793561373777289*^9, 
   3.793561396448881*^9}, {3.793561488495552*^9, 3.793561502006463*^9}, {
   3.793561541260116*^9, 3.7935615818605213`*^9}, {3.7937021045721684`*^9, 
   3.793702119181254*^9}, {3.7947309206636953`*^9, 3.794730923529991*^9}, 
   3.7947327279180317`*^9, {3.794732988900835*^9, 3.794732989505601*^9}, {
   3.794733994186968*^9, 3.7947340991227493`*^9}, {3.795344683931076*^9, 
   3.795344700037442*^9}, {3.79586700018071*^9, 
   3.795867000629442*^9}},ExpressionUUID->"1c35aff3-ce4b-4e36-8424-\
fc8afe9c5b38"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"mm", "-", 
     RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p"}], "-", "p"}], ",", 
     RowBox[{
      RowBox[{"q", "**", "p", "**", "q"}], "-", "q"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", "q"}], "-", 
      RowBox[{"adj", "[", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", "q"}], 
       "]"}]}], ",", 
     RowBox[{
      RowBox[{"q", "**", "p", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{"adj", "[", 
       RowBox[{"q", "**", "p", "**", "c", "**", 
        RowBox[{"adj", "[", "c", "]"}]}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p"}], "-", "p"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "q", "]"}], "**", 
       SubscriptBox["v", "1"]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"adj", "[", "q", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", 
       SubscriptBox["v", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}]}], "-", 
      RowBox[{"q", "**", 
       SubscriptBox["u", "1"]}]}], ",", 
     RowBox[{"q", "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}], "**", 
       SubscriptBox["u", "2"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond5", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p", "**", "q"}], "-", 
      RowBox[{"p", "**", "q"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "q", "]"}], "**", 
       SubscriptBox["v", "1"]}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "q", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", 
       SubscriptBox["v", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}]}], "-", 
      RowBox[{"q", "**", 
       SubscriptBox["u", "1"]}]}], ",", 
     RowBox[{"q", "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}], "**", 
       SubscriptBox["u", "2"]}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.760214882333124*^9, 3.7602149094953413`*^9}, {
   3.760299352310708*^9, 3.760299606916191*^9}, {3.760299734733309*^9, 
   3.760299755756258*^9}, {3.7721825126136*^9, 3.772182512921143*^9}, {
   3.782560675881798*^9, 3.7825606932215023`*^9}, {3.783711507336227*^9, 
   3.78371152893266*^9}, {3.783711846833893*^9, 3.783711850474297*^9}, {
   3.793014171220292*^9, 3.793014197724453*^9}, {3.7930796373725977`*^9, 
   3.793079638191772*^9}, {3.793205891187338*^9, 3.793205915564846*^9}, {
   3.7933687103991117`*^9, 3.793368710479081*^9}, {3.793375075948358*^9, 
   3.793375121308185*^9}, {3.793375159646665*^9, 3.7933751616050997`*^9}, {
   3.793375256893367*^9, 3.7933752573425694`*^9}, 3.7933753606773367`*^9, 
   3.793429201115258*^9, {3.79355890279408*^9, 3.793558915447351*^9}, {
   3.793558982583823*^9, 3.793559105864903*^9}, {3.79355978057474*^9, 
   3.7935597920335083`*^9}, {3.793559890995832*^9, 3.793559893056037*^9}, {
   3.7935599897970657`*^9, 3.7935599915502367`*^9}, {3.7935600779834967`*^9, 
   3.793560083078147*^9}, {3.793560115552265*^9, 3.793560120587097*^9}, {
   3.793560178951942*^9, 3.793560192254408*^9}, {3.793560275315147*^9, 
   3.793560277920981*^9}, {3.79356035583495*^9, 3.79356036180585*^9}, {
   3.793560432144408*^9, 3.793560433737459*^9}, 3.793561331847683*^9, {
   3.793561746390874*^9, 3.793561751426188*^9}, {3.7935618198263483`*^9, 
   3.793561827525302*^9}, {3.79356186180107*^9, 3.793561912310094*^9}, {
   3.79370214862015*^9, 3.7937021531441803`*^9}, {3.794732993229681*^9, 
   3.79473307196082*^9}, {3.794733106803252*^9, 3.794733146099559*^9}, {
   3.794733319285632*^9, 3.794733343398587*^9}, {3.79475143398459*^9, 
   3.79475153026162*^9}, {3.794752857072918*^9, 3.794752921566412*^9}, {
   3.7947618383675623`*^9, 3.794761838966421*^9}, {3.795344750867593*^9, 
   3.795344840045599*^9}, {3.7958503055226603`*^9, 3.795850320828349*^9}, {
   3.795850378221511*^9, 3.79585040582025*^9}, 3.7958508423168287`*^9, {
   3.795850901024637*^9, 3.7958509328253107`*^9}, {3.79585182179635*^9, 
   3.7958518379309187`*^9}, {3.795853746655965*^9, 3.795853777583577*^9}, {
   3.7958545321160383`*^9, 3.7958545328330297`*^9}, {3.795855620871806*^9, 
   3.795855622035149*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"10c5bc42-10aa-488c-acb3-c05b58398d1f"],

Cell[CellGroupData[{

Cell["(i) <=> (ii)", "Subsection",
 CellChangeTimes->{
  3.7518072352048397`*^9, {3.751820447669732*^9, 3.751820448289711*^9}, {
   3.782559296247664*^9, 3.7825592986669817`*^9}, {3.7825606441730347`*^9, 
   3.782560654594322*^9}, {3.793207205079982*^9, 3.793207207628359*^9}, {
   3.793558844049698*^9, 3.7935588453566523`*^9}, {3.7947309440673933`*^9, 
   3.794730944895259*^9}},ExpressionUUID->"b2abbb50-1000-4948-9fb3-\
beffaf4e5968"],

Cell[CellGroupData[{

Cell["(i) => (ii)", "Subsubsection",
 CellChangeTimes->{{3.79473095249856*^9, 
  3.794730954741191*^9}},ExpressionUUID->"e5d52d4e-a3f7-4abd-945b-\
31585cc8c102"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"b", "**", "bb", "**", "b"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bb"}], "+", 
      RowBox[{"bb", "**", "b", "**", "bb"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"b", "**", "bb"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"bb", "**", "b"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
       "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "mm"}], "+", 
      RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{"mm", "-", 
      RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "bb", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "**", "bb"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"bb", "**", "b"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "mm", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "mm", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
           "c"}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", "mm"}], "+", 
          RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
         "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"mm", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.749660941927601*^9, 3.74966094241926*^9}, 
   3.750266113273285*^9, {3.750266813087166*^9, 3.750266817063509*^9}, 
   3.750270623061819*^9, {3.753206247550356*^9, 3.753206250466819*^9}, {
   3.758533178409301*^9, 3.7585331811587477`*^9}, {3.760215013301125*^9, 
   3.760215024153029*^9}, 3.76022006343382*^9, {3.760220103274604*^9, 
   3.760220106447934*^9}, {3.760220223465624*^9, 3.760220223713575*^9}, 
   3.760220264278222*^9, {3.760299763397023*^9, 3.760299763610744*^9}, {
   3.76596901341002*^9, 3.765969111870859*^9}, {3.765969157597831*^9, 
   3.765969228343605*^9}, {3.765971910024521*^9, 3.765971912700705*^9}, {
   3.765975076411192*^9, 3.7659750768123703`*^9}, {3.7660739129851933`*^9, 
   3.766073913590287*^9}, {3.766486979287331*^9, 3.766486984666576*^9}, {
   3.772182478975936*^9, 3.772182538010853*^9}, {3.7721844393851624`*^9, 
   3.772184440037513*^9}, {3.772184480353422*^9, 3.77218448407648*^9}, {
   3.772184556774643*^9, 3.772184557236208*^9}, {3.772184771369567*^9, 
   3.772184778387211*^9}, {3.772185334505906*^9, 3.7721853367487698`*^9}, {
   3.772260078422312*^9, 3.772260081848974*^9}, {3.772265603686636*^9, 
   3.77226560402724*^9}, {3.772472020132512*^9, 3.772472024623268*^9}, {
   3.7727056692164783`*^9, 3.772705671277442*^9}, {3.772705781041428*^9, 
   3.7727057876739693`*^9}, {3.772706100623322*^9, 3.772706102653676*^9}, {
   3.772707439771456*^9, 3.772707444582162*^9}, {3.772708585136196*^9, 
   3.7727085902454042`*^9}, {3.77270869999089*^9, 3.772708702687204*^9}, {
   3.772709034408527*^9, 3.772709038243395*^9}, {3.772825155704142*^9, 
   3.772825188795082*^9}, {3.772825242760989*^9, 3.772825244742786*^9}, {
   3.7728256782468348`*^9, 3.7728256806425533`*^9}, {3.773135670779529*^9, 
   3.773135673256426*^9}, {3.775672356898904*^9, 3.775672357490932*^9}, {
   3.792924215880781*^9, 3.792924218259001*^9}, {3.7929243164766407`*^9, 
   3.7929243305720377`*^9}, {3.792924427530142*^9, 3.7929244275851383`*^9}, {
   3.7930142071779537`*^9, 3.793014207958685*^9}, {3.793207170123336*^9, 
   3.793207174707844*^9}, {3.794732544753358*^9, 3.7947326106710587`*^9}, {
   3.794733219479651*^9, 3.7947332302450867`*^9}, {3.795850848244894*^9, 
   3.795850850664217*^9}, {3.795850993441452*^9, 3.795851034749514*^9}, 
   3.795851066674094*^9, {3.795853164514649*^9, 3.7958532031848516`*^9}, {
   3.795853237094071*^9, 3.795853238066924*^9}, {3.7958556345666647`*^9, 
   3.7958556517655354`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"8c2e9927-ff5e-4039-9251-6f4ecd63ce6b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond2", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958508698413363`*^9, 3.795850876724701*^9}, {
  3.795851070391004*^9, 3.7958510740278254`*^9}, {3.79585138142704*^9, 
  3.795851437131403*^9}, {3.795851487048748*^9, 3.7958515222584133`*^9}, {
  3.795853209991414*^9, 3.795853211180661*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"bf7c4f65-ca79-445b-b5ba-d223a60db01c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.795851400666438*^9, 3.795851442912459*^9}, {
   3.795851497167861*^9, 3.7958515237221937`*^9}, 3.795853211732115*^9, {
   3.795853242041564*^9, 3.795853244462359*^9}, 3.795853276737007*^9, 
   3.795855325504583*^9, {3.79585537539725*^9, 3.79585539007933*^9}, {
   3.795855488483857*^9, 3.795855506659267*^9}, {3.795855669847673*^9, 
   3.795855678821106*^9}, 3.795856172279928*^9, 3.795857853076939*^9, 
   3.795857950987274*^9, 3.7958581077927513`*^9, 3.795858193964122*^9, 
   3.795858745677741*^9, 3.7958590156116667`*^9, {3.795859136173585*^9, 
   3.795859151595718*^9}},
 CellLabel->"Out[35]=",ExpressionUUID->"e7ecc410-cc9f-4a50-a395-015a22f5e8bd"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(ii) => (i)", "Subsubsection",
 CellChangeTimes->{{3.79473095249856*^9, 3.794730954741191*^9}, {
  3.7947326955499496`*^9, 
  3.794732696524206*^9}},ExpressionUUID->"f67bda2c-d6ce-45c7-b094-\
b67a26ad81e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"b", "**", "bb", "**", "b"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bb"}], "+", 
      RowBox[{"bb", "**", "b", "**", "bb"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"b", "**", "bb"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"bb", "**", "b"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
       "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "mm"}], "+", 
      RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
       "bb", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "bb", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "**", "bb"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"bb", "**", "b"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "mm", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
        "aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
        "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], ";", 
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
           "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
           "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "cc"}]}], ",", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
           "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}], "-", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b"}], 
        ",", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
           "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}], "-", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", "cc", "**",
          "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", "cc", "**",
          "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
        ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}]}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "mm", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
        "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
         "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "mm", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
          "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
           "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
        RowBox[{"aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
          "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
          "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
          "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "mm"}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"cc", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
           "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
           "bb", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{
        "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", 
         "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "mm", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "cc"}], ",", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
           "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}], "-", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b"}], 
        ",", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
           "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}], "-", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
         "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
        ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
          "c"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
         "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", "mm", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
        ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}]}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "mm", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "mm", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
           "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
        RowBox[{"aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
           "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
        RowBox[{"aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "mm", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "mm", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "mm", "**", 
         RowBox[{"adj", "[", "aa", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "mm", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}]}], ",", 
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "mm", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
        "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm"}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
        "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
          "mm"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "mm"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
          "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa", "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
         
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"c", "**", "mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "mm"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "aa", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "cc", "**", "c", "**", "mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mm", ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
         "b", "**", "c", "**", "cc", "**", "c", "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{
        "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", "mm", "**", 
         "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mm", ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", "mm"}], "+", 
         RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
        "1"}], "}"}]}], "}"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.749660941927601*^9, 3.74966094241926*^9}, 
   3.750266113273285*^9, {3.750266813087166*^9, 3.750266817063509*^9}, 
   3.750270623061819*^9, {3.753206247550356*^9, 3.753206250466819*^9}, {
   3.758533178409301*^9, 3.7585331811587477`*^9}, {3.760215013301125*^9, 
   3.760215024153029*^9}, 3.76022006343382*^9, {3.760220103274604*^9, 
   3.760220106447934*^9}, {3.760220223465624*^9, 3.760220223713575*^9}, 
   3.760220264278222*^9, {3.760299763397023*^9, 3.760299763610744*^9}, {
   3.76596901341002*^9, 3.765969111870859*^9}, {3.765969157597831*^9, 
   3.765969228343605*^9}, {3.765971910024521*^9, 3.765971912700705*^9}, {
   3.765975076411192*^9, 3.7659750768123703`*^9}, {3.7660739129851933`*^9, 
   3.766073913590287*^9}, {3.766486979287331*^9, 3.766486984666576*^9}, {
   3.772182478975936*^9, 3.772182538010853*^9}, {3.7721844393851624`*^9, 
   3.772184440037513*^9}, {3.772184480353422*^9, 3.77218448407648*^9}, {
   3.772184556774643*^9, 3.772184557236208*^9}, {3.772184771369567*^9, 
   3.772184778387211*^9}, {3.772185334505906*^9, 3.7721853367487698`*^9}, {
   3.772260078422312*^9, 3.772260081848974*^9}, {3.772265603686636*^9, 
   3.77226560402724*^9}, {3.772472020132512*^9, 3.772472024623268*^9}, {
   3.7727056692164783`*^9, 3.772705671277442*^9}, {3.772705781041428*^9, 
   3.7727057876739693`*^9}, {3.772706100623322*^9, 3.772706102653676*^9}, {
   3.772707439771456*^9, 3.772707444582162*^9}, {3.772708585136196*^9, 
   3.7727085902454042`*^9}, {3.77270869999089*^9, 3.772708702687204*^9}, {
   3.772709034408527*^9, 3.772709038243395*^9}, {3.772825155704142*^9, 
   3.772825188795082*^9}, {3.772825242760989*^9, 3.772825244742786*^9}, {
   3.7728256782468348`*^9, 3.7728256806425533`*^9}, {3.773135670779529*^9, 
   3.773135673256426*^9}, {3.775672356898904*^9, 3.775672357490932*^9}, {
   3.792924215880781*^9, 3.792924218259001*^9}, {3.7929243164766407`*^9, 
   3.7929243305720377`*^9}, {3.792924427530142*^9, 3.7929244275851383`*^9}, {
   3.7930142071779537`*^9, 3.793014207958685*^9}, {3.793207170123336*^9, 
   3.793207174707844*^9}, {3.794732544753358*^9, 3.7947326106710587`*^9}, {
   3.794732698753674*^9, 3.794732701025693*^9}, {3.794733211524482*^9, 
   3.794733211865149*^9}, {3.79585161400502*^9, 3.795851617470749*^9}, {
   3.795853323306644*^9, 3.795853328898522*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"0a99a2af-4b18-4343-a20b-1879c4be6941"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795851618722022*^9, 3.795851626114195*^9}, {
  3.795853333249713*^9, 3.795853334712084*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"4f755188-b921-4837-93e4-fdb6d32cb7d3"],

Cell[BoxData[
 RowBox[{"{", "True", "}"}]], "Output",
 CellChangeTimes->{
  3.795851627114661*^9, 3.7958533352259083`*^9, 3.7958553256804943`*^9, 
   3.795855679027903*^9, 3.79585617247027*^9, 3.795857853255722*^9, 
   3.795858194997632*^9, 3.7958587458707447`*^9, 3.7958590165122557`*^9, {
   3.7958591363568697`*^9, 3.795859151769135*^9}},
 CellLabel->"Out[37]=",ExpressionUUID->"3c8bf2e7-73c6-42cf-bb1f-46d23ff08ad3"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(ii) <=> (iii) ", "Subsection",
 CellChangeTimes->{{3.793433915821907*^9, 3.793433916813746*^9}, {
   3.793560618287649*^9, 3.793560621833213*^9}, {3.793702198196563*^9, 
   3.79370219926649*^9}, {3.794732782992634*^9, 3.794732788712646*^9}, 
   3.794733262758246*^9, {3.794733447471673*^9, 3.794733450231045*^9}, {
   3.794761729260571*^9, 3.794761731428877*^9}, {3.795858210422271*^9, 
   3.795858211005086*^9}},ExpressionUUID->"8c7216d5-e985-4f7d-81fc-\
88fca283d9c7"],

Cell[CellGroupData[{

Cell["(ii) => (iii) ", "Subsubsection",
 CellChangeTimes->{{3.794732796728485*^9, 3.7947328034185333`*^9}, 
   3.7947332621172943`*^9, {3.7947334520938396`*^9, 3.79473345374999*^9}, {
   3.794761733105175*^9, 
   3.794761734324939*^9}},ExpressionUUID->"10b859a2-3734-4fe9-88d6-\
8c126d4eccbc"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"This", " ", "holds", " ", "trivially"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.794761738921732*^9, 3.794761742509387*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"703e998e-0fa4-4e0d-a994-e49417dc6d22"]
}, Closed]],

Cell[CellGroupData[{

Cell["(iii) => (ii)", "Subsubsection",
 CellChangeTimes->{{3.794732796728485*^9, 3.7947328034185333`*^9}, {
  3.794733260744536*^9, 3.7947332640430107`*^9}, {3.794761763016541*^9, 
  3.7947617711241827`*^9}},ExpressionUUID->"9ea1b0ff-43c6-49a7-9168-\
8f06a4e3a7f3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"b", "**", "bb", "**", "b"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bb"}], "+", 
      RowBox[{"bb", "**", "b", "**", "bb"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"b", "**", "bb"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"bb", "**", "b"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
       "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "mm"}], "+", 
      RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
       "bb", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a", "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "s"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "bb", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "**", "bb"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"bb", "**", "b"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "mm", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
        "aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "s", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
        "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
            "aa", "**", "a", "**", "u"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
            "aa", "**", "a", "**", "u"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "u"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "u"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "u"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "u"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", 
            "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
            "bb", "**", "aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "u"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", 
            "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
            "bb", "**", "aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], ",", "1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], ",", "1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "w"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "w"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c",
            "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "w"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "w", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c",
            "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQfcEqzCDN+Y1j1h9mMxB97/NhJxC9bHetM4h2Y51S
BKJrvlwE09u+5tSD6JYrxWD6Pod5J4h+89UFTLeczOwH0RJ6ayeC6EDDIysX
g+jbV9eC6DLGvNsgWvXM3icgmmctz2cQfVrh3VcQfTTF6heIPtdrB6abuiax
LQHS4il/wXSe+AlpEF0z9xyYPiU1e9FLIG3yfz+YPsH758ED1zeOMwsdHoNo
9Yrz70C02i/29yDaaK2QxEMgndtnJAuir8fKaoBoG6tcXRCtoH2f7T2Qfndg
IQeInlBdZMHs8caRjXcfmP46bwMXC5C+5sLADaIBL96hTQ==
  "],
 CellLabel->"In[39]:=",ExpressionUUID->"05f0a2d9-447c-4f01-b7b5-6efe449d8291"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond2", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795851719787364*^9, 3.795851726440802*^9}, {
  3.7958534039259987`*^9, 3.7958534050525503`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"e43b8d15-14b6-45cf-b686-aaa14fa75b86"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7947332903285723`*^9, 3.794733302331609*^9}, {
   3.794733374607318*^9, 3.794733435436677*^9}, 3.7947618128023653`*^9, 
   3.795851729096693*^9, 3.7958553266620626`*^9, 3.795855679233815*^9, 
   3.7958561726730747`*^9, 3.79585785342305*^9, 3.795858195256381*^9, 
   3.795858746130368*^9, 3.7958590166935062`*^9, {3.795859136544235*^9, 
   3.795859151943104*^9}},
 CellLabel->"Out[41]=",ExpressionUUID->"a5e8735d-d216-4880-bf7a-ea48df1d1030"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (iv)", "Subsection",
 CellChangeTimes->{{3.793433915821907*^9, 3.793433916813746*^9}, {
   3.793560618287649*^9, 3.793560630032298*^9}, {3.7947327629674997`*^9, 
   3.794732777020142*^9}, 
   3.794733461044628*^9},ExpressionUUID->"70a1a771-414a-46ce-be6c-\
ff476e44d458"],

Cell[CellGroupData[{

Cell["(i) => (iv)", "Subsubsection",
 CellChangeTimes->{{3.794733465102*^9, 
  3.794733468596349*^9}},ExpressionUUID->"127ea162-3f30-41a1-9b5e-\
1fa386e2165a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"b", "**", "bb", "**", "b"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bb"}], "+", 
      RowBox[{"bb", "**", "b", "**", "bb"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"b", "**", "bb"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"bb", "**", "b"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
       "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "mm"}], "+", 
      RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{"mm", "-", 
      RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "bb", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "**", "bb"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"bb", "**", "b"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "mm", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "mm", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
           "c"}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
           "c"}]}], ",", "cc"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "mm", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "mm"}], "+", 
          RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
         "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"mm", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQfcEqzCDN+Y1j1h9mMxB97/NhJxC9bHetM4h2Y51S
BKJrvlwE09u+5tSD6JYrxWD6Pod5J4h+89UFTLeczOwH0RJ6ayeC6EDDIysX
g+jbV9eC6DLGvNsgWvXM3icgmmctz2cQfVrh3VcQfTTF6heIPtdrB6abuiax
LQHS4il/wXSe+AlpEF0z9xyYPsko2A6i+XJkwbRNNfsqEN28P3M1iJ7hL78R
RF984b0NRP85KrwHRJsIzQXTp28ePAWiA2YfAdM67/i4loLoR9f4QfQpiXML
XwLp6+y/wXS72hPjh65vHOXyLC1ANKOTbCiI7llvAaajVsy3Y/Z44/io4R6Y
VonYK8gCpOVZ5IRANAAL5bdO
  "],
 CellLabel->"In[42]:=",ExpressionUUID->"29503700-ed5e-4648-a4ef-d2d5698f7452"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond4", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795851768807033*^9, 3.7958518081318293`*^9}, {
  3.795851845029845*^9, 3.795851845455038*^9}, {3.79585348432279*^9, 
  3.795853485149835*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"5445cb18-1ef2-4e92-99d8-70c02f365bf1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.795851776972303*^9, 3.795851815322528*^9}, 
   3.795851845983564*^9, 3.795855326725528*^9, 3.795855679311789*^9, 
   3.795856172759432*^9, 3.795857854194626*^9, 3.795858196145804*^9, 
   3.79585874625885*^9, 3.795859016779867*^9, {3.795859136617416*^9, 
   3.7958591520209427`*^9}},
 CellLabel->"Out[44]=",ExpressionUUID->"fe894f60-0548-4247-9a34-f3819a45afe0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(iv) => (i)", "Subsubsection",
 CellChangeTimes->{{3.794733465102*^9, 3.794733468596349*^9}, {
  3.794733516272234*^9, 
  3.794733517982376*^9}},ExpressionUUID->"829806b2-b48b-45ab-ac70-\
20bef5755a01"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"b", "**", "bb", "**", "b"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bb"}], "+", 
      RowBox[{"bb", "**", "b", "**", "bb"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"b", "**", "bb"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"bb", "**", "b"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
       "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "mm"}], "+", 
      RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "w"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "s"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "bb", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "**", "bb"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"bb", "**", "b"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "mm", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "u", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "s", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"cc", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "s"}]}], ",", "aa"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "s"}]}], ",", "aa"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"s", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"s", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"s", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"s", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", "s", "**",
          "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", "s", "**", \
"aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", "s", "**",
          "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", "aa", "**", "a", "**", "s", "**",
          "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", 
         RowBox[{"adj", "[", "v", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "mm"}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", 
         RowBox[{"adj", "[", "v", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
        "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "aa"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", 
         RowBox[{"adj", "[", "v", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "mm", "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", 
         RowBox[{"adj", "[", "v", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", 
         RowBox[{"adj", "[", "v", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
          "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
        
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "mm", "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
        RowBox[{"aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
         
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"c", "**", "mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "mm"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "aa", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
        "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "cc", "**", "c", "**", "mm", "**", "a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mm", ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
         "b", "**", "c", "**", "cc", "**", "c", "**", "mm", "**", "a", "**", 
         "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mm", ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", "mm"}], "+", 
         RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
        "1"}], "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.795853984919599*^9, 3.795853996229175*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"4a9907d0-25e2-44c1-8930-5d48d803f745"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958518854895678`*^9, 3.795851892826339*^9}, {
  3.79585356041051*^9, 3.7958535613221073`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"d0e63c92-88b6-4913-b941-879d79563a56"],

Cell[BoxData[
 RowBox[{"{", "True", "}"}]], "Output",
 CellChangeTimes->{
  3.7958518934278803`*^9, {3.795853563223579*^9, 3.795853572136229*^9}, 
   3.795853810139001*^9, 3.795854001221126*^9, 3.795855326825135*^9, 
   3.795855679419405*^9, 3.7958561728698673`*^9, 3.795857854325754*^9, 
   3.795858196386201*^9, 3.795858746370701*^9, 3.795859017472487*^9, {
   3.795859136695252*^9, 3.7958591521128063`*^9}},
 CellLabel->"Out[47]=",ExpressionUUID->"c3353d47-73e7-41f8-b9d9-5679e452fa8e"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (v)", "Subsection",
 CellChangeTimes->{
  3.7518072352048397`*^9, {3.751820447669732*^9, 3.751820448289711*^9}, {
   3.782559296247664*^9, 3.7825592986669817`*^9}, {3.7825606441730347`*^9, 
   3.782560654594322*^9}, {3.793205798018805*^9, 3.793205800919362*^9}, {
   3.793207647872908*^9, 3.7932076542058992`*^9}, {3.793375134550901*^9, 
   3.793375135957651*^9}, 3.793375315493877*^9, {3.793558848157592*^9, 
   3.7935588495960083`*^9}, {3.7947344865014887`*^9, 
   3.7947344925107927`*^9}},ExpressionUUID->"e3cf514f-f24a-44c6-9ba7-\
9f00f5096584"],

Cell[CellGroupData[{

Cell["(i) => (v)", "Subsubsection",
 CellChangeTimes->{{3.794734503532754*^9, 
  3.7947345056933413`*^9}},ExpressionUUID->"7269dd26-e454-42f5-a233-\
722381e39c2b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"b", "**", "bb", "**", "b"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bb"}], "+", 
      RowBox[{"bb", "**", "b", "**", "bb"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"b", "**", "bb"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"bb", "**", "b"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
       "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "mm"}], "+", 
      RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{"mm", "-", 
      RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "bb", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "**", "bb"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"bb", "**", "b"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "mm", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "mm", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
           "c"}]}], ",", "cc"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "mm", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "mm"}], "+", 
          RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
         "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}], ",", 
         RowBox[{"mm", "-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
         RowBox[{"mm", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.749660941927601*^9, 3.74966094241926*^9}, 
   3.750266113273285*^9, {3.750266813087166*^9, 3.750266817063509*^9}, 
   3.750270623061819*^9, {3.753206247550356*^9, 3.753206250466819*^9}, {
   3.758533178409301*^9, 3.7585331811587477`*^9}, {3.760215013301125*^9, 
   3.760215024153029*^9}, 3.76022006343382*^9, {3.760220103274604*^9, 
   3.760220106447934*^9}, {3.760220223465624*^9, 3.760220223713575*^9}, 
   3.760220264278222*^9, {3.760299763397023*^9, 3.760299763610744*^9}, {
   3.76596901341002*^9, 3.765969111870859*^9}, {3.765969157597831*^9, 
   3.765969228343605*^9}, {3.765971910024521*^9, 3.765971912700705*^9}, {
   3.765975076411192*^9, 3.7659750768123703`*^9}, {3.7660739129851933`*^9, 
   3.766073913590287*^9}, {3.766486979287331*^9, 3.766486984666576*^9}, {
   3.772182478975936*^9, 3.772182538010853*^9}, {3.7721844393851624`*^9, 
   3.772184440037513*^9}, {3.772184480353422*^9, 3.77218448407648*^9}, {
   3.772184556774643*^9, 3.772184557236208*^9}, {3.772184771369567*^9, 
   3.772184778387211*^9}, {3.772185334505906*^9, 3.7721853367487698`*^9}, {
   3.772260078422312*^9, 3.772260081848974*^9}, {3.772265603686636*^9, 
   3.77226560402724*^9}, {3.772472020132512*^9, 3.772472024623268*^9}, {
   3.7727056692164783`*^9, 3.772705671277442*^9}, {3.772705781041428*^9, 
   3.7727057876739693`*^9}, {3.772706100623322*^9, 3.772706102653676*^9}, {
   3.772707439771456*^9, 3.772707444582162*^9}, {3.772708585136196*^9, 
   3.7727085902454042`*^9}, {3.77270869999089*^9, 3.772708702687204*^9}, {
   3.772709034408527*^9, 3.772709038243395*^9}, {3.772825155704142*^9, 
   3.772825188795082*^9}, {3.772825242760989*^9, 3.772825244742786*^9}, {
   3.7728256782468348`*^9, 3.7728256806425533`*^9}, {3.773135670779529*^9, 
   3.773135673256426*^9}, {3.775672356898904*^9, 3.775672357490932*^9}, {
   3.792924215880781*^9, 3.792924218259001*^9}, {3.7929243164766407`*^9, 
   3.7929243305720377`*^9}, {3.792924427530142*^9, 3.7929244275851383`*^9}, {
   3.7930142071779537`*^9, 3.793014207958685*^9}, {3.7932058056271877`*^9, 
   3.793205871797639*^9}, {3.793205928623801*^9, 3.793206070930561*^9}, {
   3.793206140802784*^9, 3.793206220706478*^9}, 3.79320627736724*^9, {
   3.793206317875845*^9, 3.793206408656254*^9}, {3.793368423287887*^9, 
   3.793368423524273*^9}, 3.7933685658093443`*^9, {3.7933686171054497`*^9, 
   3.7933686220310707`*^9}, 3.7933687226395397`*^9, {3.793369912282827*^9, 
   3.793369922379944*^9}, {3.793369959374721*^9, 3.793369967820301*^9}, {
   3.793373843356442*^9, 3.793373890813609*^9}, {3.793374232212386*^9, 
   3.793374248865677*^9}, {3.793375110970668*^9, 3.793375132784109*^9}, {
   3.794734512581107*^9, 3.794734546064991*^9}, {3.7958519225781*^9, 
   3.7958519262946043`*^9}, {3.795854051917647*^9, 3.79585405387589*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"74f78d69-a899-4268-b263-d405244ce8a6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond5", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795851927495943*^9, 3.7958519342641172`*^9}, {
  3.795854056605586*^9, 3.7958540576393747`*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"e7736374-9f51-44b6-9725-7b9cfaf2a3b0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7958519351818132`*^9, 3.795854059259254*^9, 3.795855326988344*^9, 
   3.795855679538487*^9, 3.7958561729602423`*^9, 3.795857854400687*^9, 
   3.7958581965471497`*^9, 3.795858746595064*^9, 3.7958590176754313`*^9, {
   3.795859136781629*^9, 3.79585915219144*^9}},
 CellLabel->"Out[50]=",ExpressionUUID->"cf1dbbd9-ae59-4859-9d69-1564c95d6786"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(v) => (i) ", "Subsubsection",
 CellChangeTimes->{{3.794734503532754*^9, 3.7947345056933413`*^9}, {
   3.794734559561419*^9, 3.794734561371579*^9}, {3.794735175510632*^9, 
   3.794735212814286*^9}, {3.794735282632886*^9, 3.794735289255904*^9}, 
   3.7958519453355417`*^9},ExpressionUUID->"a18625ba-69f2-46f0-a982-\
759e6b6732d5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"b", "**", "bb", "**", "b"}]}], ",", 
     RowBox[{
      RowBox[{"-", "bb"}], "+", 
      RowBox[{"bb", "**", "b", "**", "bb"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"b", "**", "bb"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"bb", "**", "b"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
       "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "mm"}], "+", 
      RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "w"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "s"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "b", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "bb", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "**", "bb"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"bb", "**", "b"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "mm", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "mm", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "u", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "s", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "u", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "u", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "u", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "u", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "u", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "u", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "u", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "u", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "aa", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "aa", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
          "c"}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", "aa"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
          "c"}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", "aa"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", 
          "c"}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", "c", "**", 
         "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", "c", "**", 
         "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "mm", "**", "a", "**", "b", "**", "c", "**", 
         "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "aa", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "aa", "**", "a", "**", "b", "**",
           "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "s", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "cc", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "mm"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
         "+", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
         "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
         "+", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
        
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
         "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
           "aa", "**", "a"}]}], ",", 
        RowBox[{"u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
         "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
          "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
        RowBox[{
        "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
         "bb", "**", "aa", "**", "a", "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{
        "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mm", ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
          "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "mm"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"cc", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "s"}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a", "**", "b"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "s"}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
         "mm", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], 
        ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "cc"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b"}], ",", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", "c"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "s", "**", "b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", 
         RowBox[{"adj", "[", "v", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", 
         RowBox[{"adj", "[", "v", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "mm"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"cc", ",", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", 
         RowBox[{"adj", "[", "v", "]"}], "**", 
         RowBox[{"adj", "[", "cc", "]"}], "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "b", "**", "c", "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"a", "**", "aa"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "cc"}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"aa", "**", "a"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", 
         RowBox[{"adj", "[", "v", "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "**", "cc"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", "aa"}], "+", 
         RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
         "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "cc"}], "+", 
         RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
        RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
        RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mm", ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mm", "**", "a"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "mm"}], ",", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"mm", "**", "a"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a"}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
        RowBox[{"b", "**", "c", "**", 
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"mm", "**", "a", "**", "b", "**", "c"}], "-", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], "**", 
         RowBox[{"adj", "[", "b", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "mm", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], "**", 
         RowBox[{"adj", "[", "a", "]"}], "**", 
         RowBox[{"adj", "[", "mm", "]"}], "**", "mm"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"-", "mm"}], "+", 
         RowBox[{"mm", "**", "a", "**", "b", "**", "c", "**", "mm"}]}], ",", 
        "1"}], "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.795856133322612*^9, 3.795856160613707*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"df669f95-3961-489c-bbde-1502337074c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795851970945734*^9, 3.7958519767925167`*^9}, {
  3.795854096081648*^9, 3.795854097060556*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"a0bb2937-13ac-481f-beb6-a8686c550949"],

Cell[BoxData[
 RowBox[{"{", "True", "}"}]], "Output",
 CellChangeTimes->{
  3.795856173120672*^9, 3.795857855311458*^9, 3.795858196831854*^9, 
   3.795858746791521*^9, 3.7958590178664017`*^9, {3.7958591369548187`*^9, 
   3.7958591524193077`*^9}},
 CellLabel->"Out[53]=",ExpressionUUID->"c42bb7aa-f4df-4f09-b921-9d490a0c8bb5"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 2.2", "Section",
 CellChangeTimes->{{3.7958675214634943`*^9, 
  3.795867526865468*^9}},ExpressionUUID->"be0135d7-2748-461a-9c4e-\
92203a621a32"],

Cell["\<\
To prove Theorem 2.2, the computations of Theorem 2.1 can be adopted.\
\>", "Text",
 CellChangeTimes->{{3.795867531798132*^9, 3.795867542341692*^9}, {
  3.795867576174984*^9, 
  3.795867621020945*^9}},ExpressionUUID->"f987594c-1fc6-4920-88ed-\
69eba683cae6"]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 2.3", "Section",
 CellChangeTimes->{{3.7731274281513777`*^9, 3.77312743009344*^9}, 
   3.7731335748586884`*^9, {3.775672302091146*^9, 3.775672305285179*^9}, {
   3.78256127668699*^9, 3.782561277751964*^9}, {3.78371141920049*^9, 
   3.78371144380083*^9}, {3.783830042391808*^9, 3.783830043651895*^9}, {
   3.784011844836542*^9, 3.784011846723269*^9}, {3.792591930799479*^9, 
   3.792591932519122*^9}, {3.792597161975913*^9, 3.792597165632135*^9}, 
   3.793014301058907*^9, {3.793702337281137*^9, 3.79370233844907*^9}, {
   3.794735357656836*^9, 
   3.7947353589376097`*^9}},ExpressionUUID->"49f384b4-2aaa-4c1f-8175-\
bd15fc442992"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", ",", "B", ",", "C"}], TraditionalForm]],ExpressionUUID->
  "bf937ffe-7b11-44b6-8a34-c12312a958c9"],
 " with Moore-Penrose inverses ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "\[Dagger]"], ",", 
    SuperscriptBox["C", "\[Dagger]"]}], TraditionalForm]],ExpressionUUID->
  "1fd79605-489b-4dab-8e43-1ecc09f5d13c"],
 " and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "=", 
    RowBox[{"A", " ", "B", " ", "C"}]}], TraditionalForm]],ExpressionUUID->
  "7e005009-aa2e-45d2-9214-da4808bc3e72"],
 ". Furthermore, let ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["B", "~"], TraditionalForm]],ExpressionUUID->
  "5e405c3f-059e-4401-a918-902568800596"],
 " be such that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", 
    RowBox[{"C", " ", 
     SuperscriptBox["C", "\[Dagger]"], 
     OverscriptBox["B", "~"], " ", 
     SuperscriptBox["A", "\[Dagger]"], " ", "A"}]}], TraditionalForm]],
  ExpressionUUID->"f7d35883-4441-4ea5-bb42-8275b60cdbaa"],
 " exists and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    RowBox[{
     SuperscriptBox["A", "\[Dagger]"], "A", " ", "B", " ", "C", " ", 
     SuperscriptBox["C", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "3fb3e689-65ea-4f03-9bd6-58d40d254338"],
 ". Then, the following are equivalent:\ni) M is Moore-Penrose invertible and \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["M", "\[Dagger]"], "=", 
    RowBox[{
     SuperscriptBox["C", "\[Dagger]"], 
     OverscriptBox["B", "~"], 
     SuperscriptBox["A", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "44ab304b-89de-42b7-8c72-fd8000b3497c"],
 ";\niv) Q \[Element] P{1}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "e1b1351d-e163-4032-b261-4ad206abec99"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "46c666c8-2aec-4257-8b24-14e86f2b3ef9"],
 ";\nv) M is right *-cancellable, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", " ", "Q"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"P", " ", "Q"}], ")"}], "2"]}], TraditionalForm]],
  ExpressionUUID->"43c14a0e-8fec-4823-a061-787411827fa5"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "a9a6ce43-e275-4944-a1c6-40fad807fc42"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "ff3068df-b3a6-4fad-b492-379afc3cc553"],
 ";\nvi) Q \[Element] P{2}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "b1826841-1af7-4386-a4e1-102f8d828039"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "b1b1ae31-923d-4d05-b9e1-f0b89068333a"],
 ";"
}], "Text",
 CellChangeTimes->{
  3.782560019710051*^9, {3.784004177255678*^9, 3.784004187653689*^9}, {
   3.784004426975814*^9, 3.7840044372660913`*^9}, {3.7840118407404633`*^9, 
   3.7840118420000677`*^9}, {3.784353540148328*^9, 3.784353540482725*^9}, {
   3.792591937635511*^9, 3.7925920226892548`*^9}, {3.792594996938553*^9, 
   3.792595038018059*^9}, {3.793014340269697*^9, 3.7930143593603077`*^9}, {
   3.793702364124432*^9, 3.79370237324473*^9}, {3.794735377942581*^9, 
   3.794735433136347*^9}, {3.7947362117286053`*^9, 3.794736212667563*^9}, {
   3.7958463191328297`*^9, 3.795846330398178*^9}, 3.795867807087325*^9, {
   3.795874593859743*^9, 
   3.795874613950124*^9}},ExpressionUUID->"9bcb1b39-c960-4351-9f24-\
905c25e4186f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m"}], "+", 
      RowBox[{"m", "**", "cc", "**", "bb", "**", "aa", "**", "m"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "m", "**", "cc", "**", "bb", "**", 
       "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"m", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "m", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa", "**", "m"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "m", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p"}], "-", "p"}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "q", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", 
       SubscriptBox["v", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}]}], "-", 
      RowBox[{"q", "**", 
       SubscriptBox["u", "1"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond5", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "**", "m"}], ",", 
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p", "**", "q"}], "-", 
      RowBox[{"p", "**", "q"}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "q", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", 
       SubscriptBox["v", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}]}], "-", 
      RowBox[{"q", "**", 
       SubscriptBox["u", "1"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond6", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"q", "**", "p", "**", "q"}], "-", "q"}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "q", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", 
       SubscriptBox["v", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}]}], "-", 
      RowBox[{"q", "**", 
       SubscriptBox["u", "1"]}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQ/WWFVw4XyxvHazfX54PooI+cq42BdEHg3VMg2qX8
+i0wbVxxF0TPWST8767UG0fGKlkwvcG8pmSl3hvHHrHlZSA6JGLPlNOObxw1
lZTngWiueeuXgOjUR9vA9BEvg4dngPSj9ubHILri6PU/IDrYUOMfiLY5vIzn
LJBeILsJTE/mmSIIom8vPQ6mBf/d1T8Hkk90NADRGrMkz8x0euP45vt9MK1+
Vu8BiF7w0BxM8wYGvQPRHy51g2kxwZN9zB5vHH8UXZ8EouM87ixiAdJ7uvyX
g2jby3onQHSEkhOY7pi35zyYfqF+AUQDAK8Bmgo=
  "],
 CellLabel->"In[54]:=",ExpressionUUID->"f15967c6-05a4-4d6b-860e-0eb7ccfada56"],

Cell[CellGroupData[{

Cell["(i) <=> (iv)", "Subsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.794735453277484*^9, 
  3.794735456441379*^9}},ExpressionUUID->"4022dc23-ced1-437b-8048-\
71d8f5d3b3cb"],

Cell[CellGroupData[{

Cell["(i) => (iv)", "Subsubsection",
 CellChangeTimes->{{3.794735463057385*^9, 3.794735465256774*^9}, {
  3.794735527477466*^9, 
  3.7947355287568483`*^9}},ExpressionUUID->"81383769-030d-4f09-9a8f-\
966a69df2197"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792594723807238*^9, 3.792594772013846*^9}, {3.792594959694296*^9, 
   3.792594959870349*^9}, {3.792595077347886*^9, 3.792595077691474*^9}, 
   3.7930156994482307`*^9, {3.794735468735922*^9, 3.794735559989792*^9}, {
   3.794736052219412*^9, 3.794736052425946*^9}, {3.795852473200397*^9, 
   3.79585247594785*^9}, {3.795854691259698*^9, 3.7958547026969757`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"399cac9c-0262-4499-a270-6d921f05d3ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond4", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958524773771267`*^9, 3.795852482866069*^9}, {
  3.795854707165146*^9, 3.79585470936716*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"cfc8e995-e9ed-47fb-9e2f-969507d8a16f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.795852483480247*^9, 3.795852492368127*^9}, 
   3.795855328990025*^9, 3.7958556818035107`*^9, 3.795856173318219*^9, 
   3.795857855529439*^9, 3.795858196931975*^9, 3.795858746884488*^9, 
   3.795859017962538*^9, {3.795859137049329*^9, 3.795859152486105*^9}},
 CellLabel->"Out[60]=",ExpressionUUID->"a2fcca71-d509-46dd-9949-dbd42dbb1937"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(iv) => (i)", "Subsubsection",
 CellChangeTimes->{{3.794735463057385*^9, 
  3.794735465256774*^9}},ExpressionUUID->"a91147f0-32a8-4a0f-8b03-\
421110cdf2fe"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "u", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792594723807238*^9, 3.792594772013846*^9}, {3.792594959694296*^9, 
   3.792594959870349*^9}, {3.792595077347886*^9, 3.792595077691474*^9}, 
   3.7930156994482307`*^9, {3.794735468735922*^9, 3.7947355197046824`*^9}, {
   3.7958525758348093`*^9, 3.795852579496572*^9}, {3.795854730048368*^9, 
   3.795854735223032*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"622ce238-8e97-4af6-8bf1-00c9ee098d4a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795852581071184*^9, 3.7958525861340322`*^9}, {
  3.79585475473617*^9, 3.7958547570932913`*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"0cc0c0ae-8f8a-4f57-8f36-c43b12672ede"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.79585258734958*^9, 3.7958553293431377`*^9, 3.7958556822043657`*^9, 
   3.795856173639823*^9, 3.7958578559026203`*^9, 3.79585819744602*^9, 
   3.795858747887775*^9, 3.7958590182750187`*^9, {3.79585913735767*^9, 
   3.7958591527779408`*^9}},
 CellLabel->"Out[63]=",ExpressionUUID->"b287c804-53b3-4c22-b120-1f62e8ccbe3d"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (v)", "Subsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792592208296945*^9, 
  3.7925922287915583`*^9}, {3.792595199643013*^9, 3.792595204862895*^9}, {
  3.793014412502242*^9, 3.793014427090448*^9}, {3.7930182659095373`*^9, 
  3.7930182677411203`*^9}, {3.794735578759536*^9, 3.794735583412286*^9}, {
  3.794736046522477*^9, 
  3.7947360474456987`*^9}},ExpressionUUID->"efc6422c-1a6b-4189-8353-\
27bb74bf306b"],

Cell[CellGroupData[{

Cell["(v) => (i)", "Subsubsection",
 CellChangeTimes->{{3.794735596985414*^9, 
  3.79473559862479*^9}},ExpressionUUID->"79e7460d-b32e-40a4-95ac-\
093be0bd472b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "u", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c"}], "-", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "u", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592211852914*^9, 3.792592211918508*^9}, {3.792595113183651*^9, 
   3.7925951643628283`*^9}, 3.793014662590588*^9, {3.793014715585062*^9, 
   3.793014790109746*^9}, {3.79301483770465*^9, 3.793014864349925*^9}, {
   3.7930151284022007`*^9, 3.793015155779394*^9}, 3.7930156965233727`*^9, {
   3.7930160305439873`*^9, 3.793016030782937*^9}, {3.794735600368946*^9, 
   3.794735799137484*^9}, {3.7958547913522263`*^9, 3.795854814341608*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"07d3bccc-b058-43d5-bf58-b1c211fc4523"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795854825386724*^9, 3.795854840400362*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"983a5a15-34bb-4cff-8ac5-7b77f3496052"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795855329690165*^9, 3.795855682591926*^9, 3.795856173879717*^9, 
   3.7958578561173697`*^9, 3.795858197751554*^9, 3.7958587481533127`*^9, 
   3.795859018513298*^9, {3.795859137581283*^9, 3.795859152991171*^9}},
 CellLabel->"Out[66]=",ExpressionUUID->"a94b5f74-e1ba-4da2-af29-13bfba00f2a6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) => (v)", "Subsubsection",
 CellChangeTimes->{{3.794735596985414*^9, 3.79473559862479*^9}, {
  3.794735859026401*^9, 
  3.794735860580223*^9}},ExpressionUUID->"6b6c7d7d-b384-4483-8073-\
fb180245c2f2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{"z", "**", "a", "**", "b", "**", "c", "**", 
      RowBox[{"adj", "[", "c", "]"}], "**", 
      RowBox[{"adj", "[", "b", "]"}], "**", 
      RowBox[{"adj", "[", "a", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{"a", "**", "b", "**", "c", "**", 
      RowBox[{"adj", "[", "c", "]"}], "**", 
      RowBox[{"adj", "[", "b", "]"}], "**", 
      RowBox[{"adj", "[", "a", "]"}], "**", 
      RowBox[{"adj", "[", "z", "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "z"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"z", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"z", "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592211852914*^9, 3.792592211918508*^9}, {3.792595113183651*^9, 
   3.7925951643628283`*^9}, 3.793014662590588*^9, {3.793014715585062*^9, 
   3.793014790109746*^9}, {3.79301483770465*^9, 3.793014864349925*^9}, {
   3.7930151284022007`*^9, 3.793015155779394*^9}, 3.7930156965233727`*^9, {
   3.7930160305439873`*^9, 3.793016030782937*^9}, {3.794735600368946*^9, 
   3.794735799137484*^9}, {3.794735864015525*^9, 3.794735867749941*^9}, {
   3.794735900307192*^9, 3.794736028130645*^9}, {3.795345094878065*^9, 
   3.7953451039246387`*^9}, {3.7958549397432833`*^9, 
   3.7958549592994967`*^9}, {3.795855026433242*^9, 3.7958550319515553`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"52d6c720-6af1-4894-b893-29d6e7888d99"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond5", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795855036761593*^9, 3.795855056814505*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"0bd239b0-344d-4c82-a8f3-b06020007c91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.79585532978559*^9, 3.795855682707662*^9, 3.795856173969172*^9, 
   3.795857856178327*^9, 3.795858197856353*^9, 3.79585874824205*^9, 
   3.795859018634058*^9, {3.795859137647311*^9, 3.7958591536896553`*^9}},
 CellLabel->"Out[69]=",ExpressionUUID->"d1a1a104-eb28-411e-a760-6b1e5955155c"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (vi) ", "Subsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792592208296945*^9, 
  3.792592247950362*^9}, {3.794736079545023*^9, 3.794736080273978*^9}, {
  3.79473616567969*^9, 
  3.794736166882594*^9}},ExpressionUUID->"e19130a1-a1b2-46f9-b705-\
dd2eb3599d53"],

Cell[CellGroupData[{

Cell["(i) => (vi)", "Subsubsection",
 CellChangeTimes->{{3.794736085081689*^9, 
  3.794736088372178*^9}},ExpressionUUID->"6249339b-181a-4886-b631-\
d985455f33fc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.794736135422559*^9, 3.794736149778282*^9}, {
  3.795855088854393*^9, 3.795855102662816*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"8f319ecc-da3f-4d63-b937-fe88b87bd2ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond6", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958551100222883`*^9, 3.7958551230771112`*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"1692d2b3-f3d5-4f20-a0bf-6f2f950c5e6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795855329848502*^9, 3.7958556827807007`*^9, 3.7958561740625343`*^9, 
   3.79585785623765*^9, 3.7958581979549637`*^9, 3.795858748318625*^9, 
   3.795859018711916*^9, {3.795859137713667*^9, 3.7958591538805017`*^9}},
 CellLabel->"Out[72]=",ExpressionUUID->"acb39251-af76-442f-a9d8-18e0953dc8f7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(vi) => (i)", "Subsubsection",
 CellChangeTimes->{{3.794736096434875*^9, 
  3.7947360997327147`*^9}},ExpressionUUID->"fa2917f0-e162-4662-9697-\
38f2d5f2c74b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
       "bb", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "u", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592211852914*^9, 3.792592211918508*^9}, {3.792592251362611*^9, 
   3.7925922514565983`*^9}, {3.7925954644310703`*^9, 3.792595464798995*^9}, 
   3.793015718842504*^9, {3.7947361040080643`*^9, 3.794736120708023*^9}, {
   3.7958551483010397`*^9, 3.795855159381689*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"33d98fd3-3f17-4d8e-9ea5-3f5f9015506c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958551614130573`*^9, 3.795855175372458*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"9d5a76cb-d638-4c91-afb8-e279e5006406"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7958553301276073`*^9, 3.795855683128336*^9, 3.79585617447197*^9, 
   3.795857856520606*^9, 3.79585819834525*^9, 3.795858748621303*^9, 
   3.795859018998228*^9, {3.795859138001905*^9, 3.795859154186079*^9}},
 CellLabel->"Out[75]=",ExpressionUUID->"9045f67d-1beb-4ed2-9985-8b15fbe57393"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 2.4", "Section",
 CellChangeTimes->{{3.7731274281513777`*^9, 3.77312743009344*^9}, 
   3.7731335748586884`*^9, {3.775672302091146*^9, 3.775672305285179*^9}, {
   3.78256127668699*^9, 3.782561277751964*^9}, {3.78371141920049*^9, 
   3.78371144380083*^9}, {3.783830042391808*^9, 3.783830043651895*^9}, {
   3.784011844836542*^9, 3.784011846723269*^9}, {3.792591930799479*^9, 
   3.792591932519122*^9}, {3.7925924268523273`*^9, 3.7925924270997267`*^9}, {
   3.792597163595809*^9, 3.792597166685886*^9}, 3.7930158854601*^9, {
   3.793702578994293*^9, 3.79370258017752*^9}, {3.7947361845033913`*^9, 
   3.794736186022122*^9}},ExpressionUUID->"3df7a30e-0932-4e2d-8c4c-\
5c4d2b848f94"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", ",", "B", ",", "C"}], TraditionalForm]],ExpressionUUID->
  "f52b6155-789f-440f-9692-7a9b1bb45ddd"],
 " with Moore-Penrose inverses ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "\[Dagger]"], ",", 
    SuperscriptBox["C", "\[Dagger]"]}], TraditionalForm]],ExpressionUUID->
  "85665ef7-1bf8-419a-a56e-fbb8b94307d8"],
 " and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "=", 
    RowBox[{"A", " ", "B", " ", "C"}]}], TraditionalForm]],ExpressionUUID->
  "949d357b-f46b-4562-b97f-1d57af46a2b7"],
 ". Furthermore, let ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["B", "~"], TraditionalForm]],ExpressionUUID->
  "8a33df49-42bc-4324-bdcd-e82b548155b3"],
 " be such that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", 
    RowBox[{"C", " ", 
     SuperscriptBox["C", "\[Dagger]"], 
     OverscriptBox["B", "~"], " ", 
     SuperscriptBox["A", "\[Dagger]"], " ", "A"}]}], TraditionalForm]],
  ExpressionUUID->"a22e9aaa-7163-420a-95fc-a02191d648ba"],
 " exists and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    RowBox[{
     SuperscriptBox["A", "\[Dagger]"], "A", " ", "B", " ", "C", " ", 
     SuperscriptBox["C", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "6159929b-6eff-4bda-82ff-04f8a394edd2"],
 ". Then, the following are equivalent:\ni) M is Moore-Penrose invertible and \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["M", "\[Dagger]"], "=", 
    RowBox[{
     SuperscriptBox["C", "\[Dagger]"], 
     OverscriptBox["B", "~"], 
     SuperscriptBox["A", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "9e13ea97-54bd-46c2-8a2b-648b269407f5"],
 ";\niv) Q \[Element] P{1}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "cb89c64f-ab46-45e3-8fd9-cf848a0d0380"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "4757922c-41c3-4fe8-8dad-caf4846d1697"],
 ";\nv) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["C", "\[Dagger]"], 
    OverscriptBox["B", "~"], 
    SuperscriptBox["A", "\[Dagger]"]}], TraditionalForm]],ExpressionUUID->
  "3eff1c02-8bd8-4500-9582-4fe4cae921b5"],
 " is left *-cancellable, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", " ", "Q"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"P", " ", "Q"}], ")"}], "2"]}], TraditionalForm]],
  ExpressionUUID->"eb756c03-4697-4f3e-8ee5-d6d723e63b0b"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "896df1d4-172e-4172-8c8c-2d9a87a1a1b0"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "92152735-b5c3-4a41-8085-f05ca31b17b1"],
 ";\nvi) Q \[Element] P{2}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "f1bf406a-9d0d-4289-8bbc-a00e2545c1b1"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "68e991e4-257d-47bf-a069-cebaccbfba3d"],
 ";"
}], "Text",
 CellChangeTimes->{
  3.782560019710051*^9, {3.784004177255678*^9, 3.784004187653689*^9}, {
   3.784004426975814*^9, 3.7840044372660913`*^9}, {3.7840118407404633`*^9, 
   3.7840118420000677`*^9}, {3.784353540148328*^9, 3.784353540482725*^9}, {
   3.792591937635511*^9, 3.7925920226892548`*^9}, {3.792592454900072*^9, 
   3.7925924823542557`*^9}, {3.7925960719187098`*^9, 3.79259608236524*^9}, {
   3.7930158976853333`*^9, 3.793015910624825*^9}, {3.793018284835621*^9, 
   3.79301828556703*^9}, {3.793702584006082*^9, 3.793702592539175*^9}, {
   3.794736196393495*^9, 3.794736240100582*^9}, {3.794736457915185*^9, 
   3.79473646911353*^9}, 3.795867828102788*^9, {3.795874629434265*^9, 
   3.795874636022159*^9}},ExpressionUUID->"bec067b7-08e2-43f5-9697-\
b12aa3d7fa54"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m"}], "+", 
      RowBox[{"m", "**", "cc", "**", "bb", "**", "aa", "**", "m"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "m", "**", "cc", "**", "bb", "**", 
       "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"m", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "m", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa", "**", "m"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "m", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p"}], "-", "p"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "q", "]"}], "**", 
       SubscriptBox["v", "1"]}]}], ",", 
     RowBox[{"q", "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}], "**", 
       SubscriptBox["u", "2"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond5", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cc", "**", "bb", "**", "aa", "**", "z"}], ",", 
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p", "**", "q"}], "-", 
      RowBox[{"p", "**", "q"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "q", "]"}], "**", 
       SubscriptBox["v", "1"]}]}], ",", 
     RowBox[{"q", "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}], "**", 
       SubscriptBox["u", "2"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond6", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"q", "**", "p", "**", "q"}], "-", "q"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "q", "]"}], "**", 
       SubscriptBox["v", "1"]}]}], ",", 
     RowBox[{"q", "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}], "**", 
       SubscriptBox["u", "2"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.760214882333124*^9, 3.7602149094953413`*^9}, {
  3.760299352310708*^9, 3.760299606916191*^9}, {3.760299734733309*^9, 
  3.760299755756258*^9}, {3.7721825126136*^9, 3.772182512921143*^9}, {
  3.782560675881798*^9, 3.7825606932215023`*^9}, {3.7925920378857822`*^9, 
  3.79259211309792*^9}, {3.792592165488042*^9, 3.792592165715136*^9}, {
  3.7925924982827463`*^9, 3.79259250698069*^9}, {3.7925958043356113`*^9, 
  3.792595825207398*^9}, {3.79259746293712*^9, 3.792597467474865*^9}, {
  3.793018417144764*^9, 3.79301841735536*^9}, {3.793207998716495*^9, 
  3.793208097354426*^9}, {3.793208224288185*^9, 3.793208224524776*^9}, {
  3.795856454811768*^9, 3.795856482797793*^9}, {3.795856714586018*^9, 
  3.795856714853691*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"ac2bf4c8-79be-45cf-a188-5c31a5972056"],

Cell[CellGroupData[{

Cell["(i) <=> (iv)", "Subsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.794735453277484*^9, 
  3.794735456441379*^9}},ExpressionUUID->"edd6014c-8bd6-4abe-ab4c-\
715b5fdeea3e"],

Cell[CellGroupData[{

Cell["(i) => (iv)", "Subsubsection",
 CellChangeTimes->{{3.794735463057385*^9, 3.794735465256774*^9}, {
  3.794735527477466*^9, 
  3.7947355287568483`*^9}},ExpressionUUID->"908fe205-d6bd-4620-87d7-\
86a403e0056b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792594723807238*^9, 3.792594772013846*^9}, {3.792594959694296*^9, 
   3.792594959870349*^9}, {3.792595077347886*^9, 3.792595077691474*^9}, 
   3.7930156994482307`*^9, {3.794735468735922*^9, 3.794735559989792*^9}, {
   3.794736052219412*^9, 3.794736052425946*^9}, {3.795856521869557*^9, 
   3.795856539167233*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"f2d41813-3c25-482e-80d7-a42da0950702"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond4", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795856549959319*^9, 3.795856561690549*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"8d7cca1b-d5db-4413-813a-52d9d27bef05"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795857856578336*^9, 3.795858198620035*^9, 3.795858748700539*^9, 
   3.795859019083969*^9, {3.795859138095871*^9, 3.795859154252007*^9}},
 CellLabel->"Out[82]=",ExpressionUUID->"d3780a28-4e3d-4060-8415-d884def8c576"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(iv) => (i)", "Subsubsection",
 CellChangeTimes->{{3.794735463057385*^9, 
  3.794735465256774*^9}},ExpressionUUID->"5662439b-b011-43e8-943f-\
36fe9c0656fb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "u", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", "aa"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", "aa"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", "aa"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", "aa"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "u", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792594723807238*^9, 3.792594772013846*^9}, {3.792594959694296*^9, 
   3.792594959870349*^9}, {3.792595077347886*^9, 3.792595077691474*^9}, 
   3.7930156994482307`*^9, {3.794735468735922*^9, 3.7947355197046824`*^9}, {
   3.7958565808448277`*^9, 3.79585659171786*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"53f4e43f-4099-48c9-a858-4f98c629bb53"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795856607158969*^9, 3.7958566164587927`*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"440f7f67-43da-4e28-97ce-04993ae4d929"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7958578568886147`*^9, 3.795858198950845*^9, 3.795858749053605*^9, 
   3.7958590194035263`*^9, {3.795859138408251*^9, 3.795859154573784*^9}},
 CellLabel->"Out[85]=",ExpressionUUID->"e2a664c6-d0d7-4b70-aa5e-d8f6d44a10a0"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (v)", "Subsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792592208296945*^9, 
  3.7925922287915583`*^9}, {3.792595199643013*^9, 3.792595204862895*^9}, {
  3.793014412502242*^9, 3.793014427090448*^9}, {3.7930182659095373`*^9, 
  3.7930182677411203`*^9}, {3.794735578759536*^9, 3.794735583412286*^9}, {
  3.794736046522477*^9, 
  3.7947360474456987`*^9}},ExpressionUUID->"255d8eb6-5515-4c27-b044-\
4ad14f2eaea9"],

Cell[CellGroupData[{

Cell["(v) => (i)", "Subsubsection",
 CellChangeTimes->{{3.794735596985414*^9, 
  3.79473559862479*^9}},ExpressionUUID->"5fef906c-9413-479b-a394-\
ed65d2113794"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", 
           "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
           "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
         "v", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.795856646132543*^9, 3.7958566581923227`*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"3acebea7-237f-4086-b27e-646bcf3ba85a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795856661090929*^9, 3.7958566730153503`*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"caf679f0-e078-46e5-a81a-1acb9b3799b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795857857090268*^9, 3.795858199177866*^9, 3.795858749274426*^9, 
   3.795859019656253*^9, {3.795859138621554*^9, 3.795859154802709*^9}},
 CellLabel->"Out[88]=",ExpressionUUID->"da7e9861-31cd-4017-bb26-c9495a5632ea"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) => (v)", "Subsubsection",
 CellChangeTimes->{{3.794735596985414*^9, 3.79473559862479*^9}, {
  3.794735859026401*^9, 
  3.794735860580223*^9}},ExpressionUUID->"f3c223f0-a31d-4d02-a9d3-\
6e1458a600f9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "aa", "]"}], "**", 
      RowBox[{"adj", "[", "bb", "]"}], "**", 
      RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa", "**",
       "z"}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "z", "]"}], "**", 
      RowBox[{"adj", "[", "aa", "]"}], "**", 
      RowBox[{"adj", "[", "bb", "]"}], "**", 
      RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa"}]}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "z"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "z"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "z"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592211852914*^9, 3.792592211918508*^9}, {3.792595113183651*^9, 
   3.7925951643628283`*^9}, 3.793014662590588*^9, {3.793014715585062*^9, 
   3.793014790109746*^9}, {3.79301483770465*^9, 3.793014864349925*^9}, {
   3.7930151284022007`*^9, 3.793015155779394*^9}, 3.7930156965233727`*^9, {
   3.7930160305439873`*^9, 3.793016030782937*^9}, {3.794735600368946*^9, 
   3.794735799137484*^9}, {3.794735864015525*^9, 3.794735867749941*^9}, {
   3.794735900307192*^9, 3.794736028130645*^9}, {3.794736571416807*^9, 
   3.7947365970237713`*^9}, {3.795345257577396*^9, 3.795345263202899*^9}, {
   3.7958567478089943`*^9, 3.795856770875926*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"a27b02fc-aa71-445f-bfc9-c76117427291"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond5", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795856778651472*^9, 3.795856795527994*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"ff6d904a-fdf3-4b08-b533-ac3582fd5897"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795857857147105*^9, 3.7958581992757683`*^9, 3.795858749358973*^9, 
   3.795859019747283*^9, {3.795859138691175*^9, 3.795859154867662*^9}},
 CellLabel->"Out[91]=",ExpressionUUID->"1dc6c1c4-ab4d-473c-a156-87fdb8251583"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (vi) ", "Subsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792592208296945*^9, 
  3.792592247950362*^9}, {3.794736079545023*^9, 3.794736080273978*^9}, {
  3.79473616567969*^9, 
  3.794736166882594*^9}},ExpressionUUID->"f9586a57-ef53-48f0-b2a0-\
fc3458476bfe"],

Cell[CellGroupData[{

Cell["(i) => (vi)", "Subsubsection",
 CellChangeTimes->{{3.794736085081689*^9, 
  3.794736088372178*^9}},ExpressionUUID->"ad4c1520-311d-4c7d-a421-\
a49e851fccef"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.794736135422559*^9, 3.794736149778282*^9}, {
  3.795856808101551*^9, 3.7958568261551247`*^9}, {3.7958568654581423`*^9, 
  3.795856871841464*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"6420aa15-3e06-477a-94a3-83bd138e373b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond6", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.79585683183433*^9, 3.7958568436485786`*^9}, {
  3.79585687412574*^9, 3.7958568762200813`*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"140ec08d-7141-4236-b602-fe69ff17aa3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7958578571951923`*^9, 3.795858199390689*^9, 3.795858749452868*^9, 
   3.795859019830021*^9, {3.795859138765644*^9, 3.795859154934973*^9}},
 CellLabel->"Out[94]=",ExpressionUUID->"44278999-bada-4ded-ac1f-9f5a873eb245"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(vi) => (i)", "Subsubsection",
 CellChangeTimes->{{3.794736096434875*^9, 
  3.7947360997327147`*^9}},ExpressionUUID->"78d4b843-615f-4748-b17c-\
cec0a13260ae"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
       "bb", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc",
            "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592211852914*^9, 3.792592211918508*^9}, {3.792592251362611*^9, 
   3.7925922514565983`*^9}, {3.7925954644310703`*^9, 3.792595464798995*^9}, 
   3.793015718842504*^9, {3.7947361040080643`*^9, 3.794736120708023*^9}, {
   3.795856897485858*^9, 3.795856915668149*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"738b4004-31fa-49cc-bb4a-f3d10406cdfd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958569262111063`*^9, 3.7958569518633013`*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"fd31c68f-e878-4bb6-b0a6-3826b239a90b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795857857448832*^9, 3.795858199669608*^9, 3.795858749737372*^9, 
   3.795859020118573*^9, {3.795859139037299*^9, 3.795859155210744*^9}},
 CellLabel->"Out[97]=",ExpressionUUID->"eca4cf7e-c889-4350-ae6f-a5adcd2a21c3"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 2.6", "Section",
 CellChangeTimes->{{3.7731274281513777`*^9, 3.77312743009344*^9}, 
   3.7731335748586884`*^9, {3.775672302091146*^9, 3.775672305285179*^9}, {
   3.78256127668699*^9, 3.782561277751964*^9}, {3.78371141920049*^9, 
   3.78371144380083*^9}, {3.783830042391808*^9, 3.783830043651895*^9}, {
   3.784011844836542*^9, 3.784011846723269*^9}, {3.792591930799479*^9, 
   3.792591932519122*^9}, {3.7925924268523273`*^9, 3.7925924270997267`*^9}, {
   3.792592715694499*^9, 3.7925927157857428`*^9}, {3.793702710484229*^9, 
   3.793702718382728*^9}, {3.794736776144649*^9, 
   3.794736777316654*^9}},ExpressionUUID->"e2fc71b6-f8f2-499b-b2a9-\
2ecd2380fc5c"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", ",", "B", ",", "C"}], TraditionalForm]],ExpressionUUID->
  "900d3710-5340-4c02-81d2-372520982426"],
 " with Moore-Penrose inverses ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "\[Dagger]"], ",", 
    SuperscriptBox["C", "\[Dagger]"]}], TraditionalForm]],ExpressionUUID->
  "9bcbd7b3-c85b-494b-852b-779687421b21"],
 " and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "=", 
    RowBox[{"A", " ", "B", " ", "C"}]}], TraditionalForm]],ExpressionUUID->
  "4870a1d1-bda5-4d4f-bb3d-8100583a233b"],
 ". Furthermore, let ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["B", "~"], TraditionalForm]],ExpressionUUID->
  "d44bc089-cb60-445f-871e-f5e8ff93b805"],
 " be such that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", 
    RowBox[{"C", " ", 
     SuperscriptBox["C", "\[Dagger]"], 
     OverscriptBox["B", "~"], " ", 
     SuperscriptBox["A", "\[Dagger]"], " ", "A"}]}], TraditionalForm]],
  ExpressionUUID->"bd29dede-6bf4-47f4-b75c-5d9eaff920e0"],
 " exists and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    RowBox[{
     SuperscriptBox["A", "\[Dagger]"], "A", " ", "B", " ", "C", " ", 
     SuperscriptBox["C", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "ba4031e1-95b5-4b60-8eab-84f953e34c81"],
 ". Then, the following are equivalent:\ni) M is Moore-Penrose invertible and \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["M", "\[Dagger]"], "=", 
    RowBox[{
     SuperscriptBox["C", "\[Dagger]"], 
     OverscriptBox["B", "~"], 
     SuperscriptBox["A", "\[Dagger]"]}]}], TraditionalForm]],ExpressionUUID->
  "d29f9378-c493-4796-8410-7cc26635f552"],
 ";\niv) Q \[Element] P{1}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "4899e212-6d61-4f6e-a744-34fc18e3dcba"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "e31421c8-57b3-4c87-8d28-0feff7f52bb4"],
 ";\nvi) Q \[Element] P{2}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "f9769836-8c5d-468e-bdcb-3d1332c156a9"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "90379f60-8a6f-417d-9f5a-93d4cd61eff5"],
 ";"
}], "Text",
 CellChangeTimes->{
  3.782560019710051*^9, {3.784004177255678*^9, 3.784004187653689*^9}, {
   3.784004426975814*^9, 3.7840044372660913`*^9}, {3.7840118407404633`*^9, 
   3.7840118420000677`*^9}, {3.784353540148328*^9, 3.784353540482725*^9}, {
   3.792591937635511*^9, 3.7925920226892548`*^9}, {3.792592454900072*^9, 
   3.7925924823542557`*^9}, {3.792592723525478*^9, 3.792592764341367*^9}, 
   3.792596111737542*^9, {3.793702729331505*^9, 3.793702739490532*^9}, {
   3.794736783980526*^9, 3.794736803960812*^9}, 3.795867840741247*^9, {
   3.7958746460260963`*^9, 
   3.795874649305636*^9}},ExpressionUUID->"84ae6721-a346-4f93-8863-\
f8d044a2d300"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m"}], "+", 
      RowBox[{"m", "**", "cc", "**", "bb", "**", "aa", "**", "m"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "m", "**", "cc", "**", "bb", "**", 
       "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"m", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "m", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa", "**", "m"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "m", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p"}], "-", "p"}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "q", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", 
       SubscriptBox["v", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}], "**", 
       SubscriptBox["u", "2"]}], "-", "q"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond6", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"q", "**", "p", "**", "q"}], "-", "q"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "q", "]"}], "**", 
       SubscriptBox["v", "1"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}]}], "-", 
      RowBox[{"q", "**", 
       SubscriptBox["u", "1"]}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.760214882333124*^9, 3.7602149094953413`*^9}, {
  3.760299352310708*^9, 3.760299606916191*^9}, {3.760299734733309*^9, 
  3.760299755756258*^9}, {3.7721825126136*^9, 3.772182512921143*^9}, {
  3.782560675881798*^9, 3.7825606932215023`*^9}, {3.7925920378857822`*^9, 
  3.79259211309792*^9}, {3.792592165488042*^9, 3.792592165715136*^9}, {
  3.7925924982827463`*^9, 3.79259250698069*^9}, {3.792592783298334*^9, 
  3.7925928367895308`*^9}, {3.79259614068655*^9, 3.7925961543012867`*^9}, {
  3.793016740680879*^9, 3.793016742101798*^9}, {3.795857044447446*^9, 
  3.795857086745442*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"75c1efc3-5a5c-47a4-9e4f-88ad07da0c6e"],

Cell[CellGroupData[{

Cell["(i) <=> (iv) ", "Subsection",
 CellChangeTimes->{
  3.7518072352048397`*^9, {3.751820447669732*^9, 3.751820448289711*^9}, {
   3.782559296247664*^9, 3.7825592986669817`*^9}, {3.7825606441730347`*^9, 
   3.782560654594322*^9}, {3.793205798018805*^9, 3.793205800919362*^9}, {
   3.793207647872908*^9, 3.7932076542058992`*^9}, {3.793208285053884*^9, 
   3.793208288749365*^9}, {3.793208638326578*^9, 3.79320864294422*^9}, {
   3.794736821772341*^9, 
   3.794736824342033*^9}},ExpressionUUID->"4d49a244-dc14-4153-b4d7-\
28d0f4996ed1"],

Cell[CellGroupData[{

Cell["(i) => (iv)", "Subsubsection",
 CellChangeTimes->{{3.7947368347303867`*^9, 
  3.7947368378609962`*^9}},ExpressionUUID->"837d1d9f-935b-49f6-b7e2-\
196c10fa5186"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7932084696928453`*^9, 3.793208497820673*^9}, {
  3.7933756494670687`*^9, 3.793375653922347*^9}, {3.794736844206737*^9, 
  3.794736885650077*^9}, {3.795857127990683*^9, 3.79585713709546*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"1fbd5cfe-6788-4b24-9494-ffb0a088d469"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond4", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857141667704*^9, 3.7958571605528183`*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"089fb0da-5886-4848-85ca-aeb04ea93366"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7958578575467367`*^9, 3.79585819976458*^9, 3.795858749818465*^9, 
   3.795859020200465*^9, {3.795859139129431*^9, 3.795859155281884*^9}},
 CellLabel->
  "Out[103]=",ExpressionUUID->"b8787efb-b19c-4adc-b7c1-3c8c4d8c6eda"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(iv) => (i)", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 
  3.7925921382569304`*^9}},ExpressionUUID->"52a1f6d6-65ad-40db-9fc6-\
7f59a29116c2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "u", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", "aa"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", "aa"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "v"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "v", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592848262369*^9, 3.792592848432878*^9}, {3.792596168605979*^9, 
   3.792596168765706*^9}, {3.792925093562318*^9, 3.7929251489755096`*^9}, {
   3.7930167509681892`*^9, 3.79301677188937*^9}, {3.7947369052808647`*^9, 
   3.7947369204959917`*^9}, {3.795857173076406*^9, 3.795857182489856*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"6241b1be-f6ee-41cb-b0df-b8317b25cd44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857186211046*^9, 3.795857197635508*^9}, 
   3.795858416975595*^9},
 CellLabel->
  "In[106]:=",ExpressionUUID->"e843e1b3-2cfb-424d-9c8e-db7c0f16d40f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795857901148362*^9, {3.795858401849284*^9, 3.795858417776947*^9}, 
   3.795858750076503*^9, 3.7958590203844757`*^9, {3.795859139311932*^9, 
   3.79585915546033*^9}},
 CellLabel->
  "Out[106]=",ExpressionUUID->"00db6c6c-e994-42f5-886d-c81b3ef894f1"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (vi) ", "Subsection",
 CellChangeTimes->{
  3.7518072352048397`*^9, {3.751820447669732*^9, 3.751820448289711*^9}, {
   3.782559296247664*^9, 3.7825592986669817`*^9}, {3.7825606441730347`*^9, 
   3.782560654594322*^9}, {3.793205798018805*^9, 3.793205800919362*^9}, {
   3.793207647872908*^9, 3.7932076542058992`*^9}, {3.793208285053884*^9, 
   3.793208288749365*^9}, {3.793208638326578*^9, 3.79320864294422*^9}, {
   3.794736821772341*^9, 3.794736824342033*^9}, {3.794736941743765*^9, 
   3.7947369421731977`*^9}},ExpressionUUID->"643a5cde-bdf5-4284-b958-\
f2a355cab662"],

Cell[CellGroupData[{

Cell["(i) => (vi)", "Subsubsection",
 CellChangeTimes->{{3.7947368347303867`*^9, 3.7947368378609962`*^9}, {
  3.794736943285144*^9, 
  3.7947369440790462`*^9}},ExpressionUUID->"ef2ed039-6b29-40f6-be0b-\
8ad4be6c798a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c", "**", "cc", 
          "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7932084696928453`*^9, 3.793208497820673*^9}, {
  3.7933756494670687`*^9, 3.793375653922347*^9}, {3.794736844206737*^9, 
  3.794736885650077*^9}, {3.794736948118375*^9, 3.7947369507733917`*^9}, {
  3.79585721339895*^9, 3.7958572208305073`*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"437ae619-60f7-483c-97ef-b644f1faf80a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond6", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857226582026*^9, 3.795857236782173*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"f1106bf2-21d5-49a9-8172-3a51b6304c42"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795858424097266*^9, 3.795858750150407*^9, 3.795859020463463*^9, {
   3.795859139381341*^9, 3.7958591555264797`*^9}},
 CellLabel->
  "Out[109]=",ExpressionUUID->"cbf82826-7b95-45fe-844e-a538840f4f36"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(vi) => (i)", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.7947369450301523`*^9, 
  3.794736945414921*^9}},ExpressionUUID->"a40fae15-4892-4fac-a9c5-\
86ffb6c2730d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
       "bb", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "u", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
           "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "v"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"v", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "v", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", "v", "**",
           "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", "c", "**", "cc", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "u", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "u"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", 
           "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "b", "**", "c", "**", "cc", "**",
           "bb", "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592848262369*^9, 3.792592848432878*^9}, {3.792596168605979*^9, 
   3.792596168765706*^9}, {3.792925093562318*^9, 3.7929251489755096`*^9}, {
   3.7930167509681892`*^9, 3.79301677188937*^9}, {3.7947369052808647`*^9, 
   3.7947369204959917`*^9}, {3.7947369546009693`*^9, 
   3.7947369546626472`*^9}, {3.795857249613228*^9, 3.7958572579593163`*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"941ee578-2982-4434-8a44-46d60e519726"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857263719714*^9, 3.7958572736312637`*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"3d450d78-96dd-44fd-a692-130a905b94f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795858427954513*^9, 3.795858750318104*^9, 3.795859020666394*^9, {
   3.79585913956968*^9, 3.795859155694323*^9}},
 CellLabel->
  "Out[112]=",ExpressionUUID->"16a0967d-c5c7-497c-b423-f0a8e68e282e"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 2.7", "Section",
 CellChangeTimes->{{3.7731274281513777`*^9, 3.77312743009344*^9}, 
   3.7731335748586884`*^9, {3.775672302091146*^9, 3.775672305285179*^9}, {
   3.78256127668699*^9, 3.782561277751964*^9}, {3.78371141920049*^9, 
   3.78371144380083*^9}, {3.783830042391808*^9, 3.783830043651895*^9}, {
   3.784011844836542*^9, 3.784011846723269*^9}, {3.792591930799479*^9, 
   3.792591932519122*^9}, {3.7925924268523273`*^9, 3.7925924270997267`*^9}, {
   3.792592715694499*^9, 3.7925927157857428`*^9}, {3.792593037126677*^9, 
   3.792593037218049*^9}, {3.792597143168803*^9, 3.7925971492549667`*^9}, {
   3.7930167953956947`*^9, 3.793016796699814*^9}, {3.7937028006819344`*^9, 
   3.793702801497733*^9}, {3.79473698779006*^9, 
   3.7947369894260693`*^9}},ExpressionUUID->"0c6a2b2d-b9d6-411d-a5bd-\
0117f78fcb33"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", ",", "B", ",", "C"}], TraditionalForm]],ExpressionUUID->
  "dcef462d-c420-4095-a2a8-8906762cbdc7"],
 " with inverses ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]], ",", 
    SuperscriptBox["C", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4"}], "}"}]]}], TraditionalForm]],
  ExpressionUUID->"36ad7948-6274-4d96-ab49-4358735634b7"],
 " and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "=", 
    RowBox[{"A", " ", "B", " ", "C"}]}], TraditionalForm]],ExpressionUUID->
  "e09a2978-6cdf-439b-9c72-bc67ebba5bb2"],
 ". Let ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["B", "~"], TraditionalForm]],ExpressionUUID->
  "0e4ffbbf-a897-4d8d-b197-307351047276"],
 " be such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", 
    RowBox[{"C", " ", 
     SuperscriptBox["C", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "4"}], "}"}]], 
     OverscriptBox["B", "~"], " ", 
     SuperscriptBox["A", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}]], " ", "A"}]}], 
   TraditionalForm]],ExpressionUUID->"5037f8cb-cd69-4c91-91f6-450256506a8f"],
 " exists and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    RowBox[{
     SuperscriptBox["A", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "A", " ", "B", " ", "C", 
     " ", 
     SuperscriptBox["C", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "4"}], "}"}]]}]}], TraditionalForm]],
  ExpressionUUID->"91f9aced-3190-4e72-b29d-64ba13c2f900"],
 ". Furthermore, let ABC be right *-cancellable and let ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["C", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4"}], "}"}]], 
    OverscriptBox["B", "~"], 
    SuperscriptBox["A", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]]}], TraditionalForm]],
  ExpressionUUID->"2860ccf4-27cb-420b-a3c8-046bdda6bc94"],
 " be left *-cancellable. Then, the following are equivalent:\ni) M is \
Moore-Penrose invertible and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["M", "\[Dagger]"], "=", 
    RowBox[{
     SuperscriptBox["C", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "4"}], "}"}]], 
     OverscriptBox["B", "~"], 
     SuperscriptBox["A", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}]]}]}], TraditionalForm]],
  ExpressionUUID->"506fd764-6f3b-47f5-a39b-b2b3a9cb558b"],
 ";\nii) Q \[Element] P{1,2} and both of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "*"], "A", " ", "P", " ", "Q"}], TraditionalForm]],
  ExpressionUUID->"fd123d3c-049f-46b5-bc7c-4b9cf5dda3f2"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", " ", "P", " ", "C", " ", 
    SuperscriptBox["C", "*"]}], TraditionalForm]],ExpressionUUID->
  "aece3cdb-8c72-45fb-b51b-deb1df708154"],
 " are Hermitian;\niii) Q \[Element] P{1,2} and both of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["A", "*"], "A", " ", "P", " ", "Q"}], TraditionalForm]],
  ExpressionUUID->"6e125267-c9ed-490a-883b-b6ad3f70f9fb"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", " ", "P", " ", "C", " ", 
    SuperscriptBox["C", "*"]}], TraditionalForm]],ExpressionUUID->
  "b5a3b74e-ccc9-488b-aa8d-60ac3d6a32e1"],
 " are EP;\niv) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", " ", "Q"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"P", " ", "Q"}], ")"}], "2"]}], TraditionalForm]],
  ExpressionUUID->"f4d02ba7-c340-48b9-a6c7-b73c13e6f1ba"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "404b4c0e-1ccf-4b39-b5e5-a54e4fdee2fe"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "b4a2247e-43dd-484e-ab61-9bdc4ded4c41"],
 ";\nv) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", " ", "Q"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"P", " ", "Q"}], ")"}], "2"]}], TraditionalForm]],
  ExpressionUUID->"9ec964b7-11c2-455f-b08b-deb083731f6c"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{
      SuperscriptBox["A", "*"], "A", " ", "P"}], ")"}], "\[SubsetEqual]", 
    RowBox[{"R", "(", 
     SuperscriptBox["Q", "*"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "0bdaca42-849f-4884-bb9b-ef582c22c182"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", "(", 
     RowBox[{"C", " ", 
      SuperscriptBox["C", "*"], 
      SuperscriptBox["P", "*"]}], ")"}], "\[SupersetEqual]", 
    RowBox[{"R", "(", "Q", ")"}]}], TraditionalForm]],ExpressionUUID->
  "f36d8b14-f6cb-4b44-b185-7a90c2c7a8ac"],
 ";"
}], "Text",
 CellChangeTimes->{
  3.782560019710051*^9, {3.784004177255678*^9, 3.784004187653689*^9}, {
   3.784004426975814*^9, 3.7840044372660913`*^9}, {3.7840118407404633`*^9, 
   3.7840118420000677`*^9}, {3.784353540148328*^9, 3.784353540482725*^9}, {
   3.792591937635511*^9, 3.7925920226892548`*^9}, {3.792592454900072*^9, 
   3.7925924823542557`*^9}, {3.792592723525478*^9, 3.792592764341367*^9}, {
   3.7925940450277977`*^9, 3.792594141496949*^9}, {3.792594237244446*^9, 
   3.79259427780888*^9}, {3.792594486867444*^9, 3.792594598299385*^9}, {
   3.792596222782906*^9, 3.792596259232937*^9}, {3.793017052065097*^9, 
   3.7930171021115513`*^9}, {3.793378932343788*^9, 3.7933789330092897`*^9}, {
   3.7937028097259493`*^9, 3.793702817393694*^9}, {3.794737014760446*^9, 
   3.794737052126553*^9}, {3.7947521694891863`*^9, 3.7947521725643044`*^9}, 
   3.795867855668392*^9, {3.795874656308373*^9, 
   3.7958746625484343`*^9}},ExpressionUUID->"b8e9d454-c1bc-41b2-a7bd-\
234f970aebbf"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m"}], "+", 
      RowBox[{"m", "**", "cc", "**", "bb", "**", "aa", "**", "m"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "m", "**", "cc", "**", "bb", "**", 
       "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"m", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "m", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa", "**", "m"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "m", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p"}], "-", "p"}], ",", 
     RowBox[{
      RowBox[{"q", "**", "p", "**", "q"}], "-", "q"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", "q"}], "-", 
      RowBox[{"adj", "[", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", "q"}], 
       "]"}]}], ",", 
     RowBox[{
      RowBox[{"q", "**", "p", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{"adj", "[", 
       RowBox[{"q", "**", "p", "**", "c", "**", 
        RowBox[{"adj", "[", "c", "]"}]}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p", "**", "q"}], "-", 
      RowBox[{"p", "**", "q"}]}], ",", 
     RowBox[{
      RowBox[{"adj", "[", "q", "]"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p", "**", 
       SubscriptBox["v", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}]}], "-", 
      RowBox[{"q", "**", 
       SubscriptBox["u", "1"]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond5", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "**", "q", "**", "p", "**", "q"}], "-", 
      RowBox[{"p", "**", "q"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "p"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "q", "]"}], "**", 
       SubscriptBox["v", "1"]}]}], ",", 
     RowBox[{"q", "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "p", "]"}], "**", 
       SubscriptBox["u", "2"]}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwdxW0o43EAB/DRuQxdXWNllxdmded0l26FXffC7z/sbNOxdk7dCyG5F57S
ukOyJE9RUqLrpCU17h/zStSlG8rTn1HaZd26ay3j/DAPaXRb/t/fi0+f1MoG
U3W0RCJRivD1lL427gEl7gNHAzZdSHm1eGOJdxPnffnlYaubvXhsQhbxKiiJ
ak1hz2W3WaZfUjIgt3/G5rIfw1uEknRl2jiOG3dM4mrfPJtLKNzBuxXlLnzd
f3yB3dqvIVwwOZooiAftmiQ8VVCTjFfDggoPfKrPwZecXosn9p7qcJ05YMS5
3bdmPOQb+4i/22qbccerbfY8r2vHZzY9W06KHLjLObeAUwzFh9vihzLFEd75
LZxjLS8NYk76zvCNo+S5JWDEvJMvxrOaFXZfa9oW7mzJYA8GTy0h8UzlHTvr
vf2vXkuJf3Sa/WRxec0gHpmxbuD/1iYXLn1s82Bj4sKbIvHVn4vsm1gn+ZdP
ybNAL4flXlsJ3ic+Ew5lrZfipZWqD/io5+Q2XkfJ60x1GPcKx1cxbylRFb64
wyeP+AieGRmJeig+lOdZwir/H/Y9mBobEg==
  "],
 CellLabel->
  "In[113]:=",ExpressionUUID->"bbe0e934-a1c4-4c60-91b4-d41dd3ac54d6"],

Cell[CellGroupData[{

Cell["(i) <=> (ii)", "Subsection",
 CellChangeTimes->{{3.794737093841639*^9, 
  3.794737100703017*^9}},ExpressionUUID->"2af7b074-380b-4e85-93ed-\
ef55dcce24f7"],

Cell[CellGroupData[{

Cell["(i) => (ii)", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792593678079088*^9, 
  3.792593678673172*^9}, {3.793377057870475*^9, 3.7933770586643972`*^9}, {
  3.794737086934228*^9, 
  3.794737087501616*^9}},ExpressionUUID->"f40c0657-670c-4e6e-b93e-\
639e8cd6e6e2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592848262369*^9, 3.792592848432878*^9}, {3.792593646239861*^9, 
   3.792593650802047*^9}, {3.792593684809256*^9, 3.792593725101365*^9}, {
   3.7925968365712433`*^9, 3.792596836948386*^9}, 3.79301715556467*^9, {
   3.793377061941378*^9, 3.793377095543686*^9}, {3.793377133715619*^9, 
   3.79337713760585*^9}, {3.7933772115422792`*^9, 3.793377212001401*^9}, {
   3.793378661273677*^9, 3.7933786981995697`*^9}, {3.79337882470848*^9, 
   3.793378845675589*^9}, {3.7933802639109364`*^9, 3.793380264062676*^9}, {
   3.794737109170035*^9, 3.794737172449264*^9}, {3.794752045902959*^9, 
   3.794752061662653*^9}, {3.795857442183176*^9, 3.795857449175234*^9}},
 CellLabel->
  "In[117]:=",ExpressionUUID->"8380b620-8f29-49b5-b288-7876484712bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond2", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857453179817*^9, 3.795857463388589*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"b7299426-ab3e-4871-88da-e6af9be32e0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795858435872842*^9, 3.7958587503986397`*^9, 3.795859020750607*^9, {
   3.7958591396448927`*^9, 3.795859155784408*^9}},
 CellLabel->
  "Out[119]=",ExpressionUUID->"0858501f-e199-4fce-8dc2-1a33d35c978f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(ii) => (i)", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792593678079088*^9, 
  3.792593678673172*^9}},ExpressionUUID->"dc8a3cda-f717-4af1-a31e-\
d7eb837efb24"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
       "bb", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
        "aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
        "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", 
           "c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "c"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{
         "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", 
          "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
            "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
            "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**",
           "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592848262369*^9, 3.792592848432878*^9}, {3.792593646239861*^9, 
   3.792593650802047*^9}, {3.792593684809256*^9, 3.792593725101365*^9}, {
   3.7925968365712433`*^9, 3.792596836948386*^9}, 3.79301715556467*^9, {
   3.793380282919132*^9, 3.793380302524837*^9}, {3.7947371856656637`*^9, 
   3.794737222271027*^9}, {3.7958574788071337`*^9, 3.7958574874148912`*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"19112fc8-7c49-4431-ae2e-ad64d1805bd0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857491841322*^9, 3.795857501427627*^9}},
 CellLabel->
  "In[122]:=",ExpressionUUID->"d975d93f-5a0e-4d23-94a4-78904c1140d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.795858438577331*^9, 3.7958587505034723`*^9, 
  3.795859020917543*^9, 3.79585915597162*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"786fa198-ee57-4fa8-8f85-a86e1a454608"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(ii) <=> (iii)", "Subsection",
 CellChangeTimes->{{3.7947372444415617`*^9, 3.794737248044367*^9}, {
  3.794737318140571*^9, 3.794737321235774*^9}, {3.7947522135769567`*^9, 
  3.794752213788742*^9}, {3.794761954074757*^9, 
  3.7947619552562838`*^9}},ExpressionUUID->"c71deb49-a3c5-4b3f-92b7-\
8ceb54ff4391"],

Cell[CellGroupData[{

Cell["(ii) => (iii)", "Subsubsection",
 CellChangeTimes->{{3.794737253368424*^9, 3.794737265551622*^9}, {
   3.794737323029872*^9, 3.7947373246404123`*^9}, {3.7947522098385487`*^9, 
   3.794752211392562*^9}, 
   3.794761957162506*^9},ExpressionUUID->"dfd1d489-17cd-4522-9a4f-\
2c84bcf66ab4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"This", " ", "trivially", " ", "holds"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7947372669240007`*^9, 3.7947372738162537`*^9}, {
  3.794752070780011*^9, 3.794752132165147*^9}, {3.7947521940301867`*^9, 
  3.794752238947055*^9}, {3.794761960790687*^9, 3.7947619691034107`*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"23624354-ffe0-44ba-814b-b0989e4ab416"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(iii) => (ii)", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
   3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792593735737596*^9, 
   3.7925937360341043`*^9}, {3.7947372361572742`*^9, 3.7947372388773413`*^9}, 
   3.79476197230847*^9},ExpressionUUID->"8e5024df-e4ec-4657-93a3-\
282dee39ecf1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", 
       "bb", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a", "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], ",", 
     RowBox[{
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "w"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
      "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
       "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
        "aa", "**", "a"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "v", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "w", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", 
        "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc"}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}],
          ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}],
          ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
            "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**",
           "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c"}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
            "aa", "**", "a"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
            "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**",
            "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
             "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "s", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
             "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "s", "]"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "s", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], ",", "1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], ",", "1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
           "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], 
         ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
           "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**",
            "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**",
            "bb", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          
          RowBox[{"adj", "[", "c", "]"}], "**", "s"}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.795858981305794*^9, 3.795858995935017*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"ad742d80-5b4b-43bf-9496-f9bda0c65562"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond2", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958587581614323`*^9, 3.79585879000561*^9}, {
  3.7958590254594727`*^9, 3.795859029003004*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"157b99dc-ce60-4163-a834-cee7b7aa3b2b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.795858760459322*^9, 3.795858791176457*^9}, {
   3.7958589987953033`*^9, 3.795859033684511*^9}, 3.7958591561507072`*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"073baf88-c514-40db-93ba-fed23c0a9505"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (iv)", "Subsection",
 CellChangeTimes->{{3.794749208661895*^9, 
  3.7947492135687933`*^9}},ExpressionUUID->"28e87859-37dc-4f1c-bda7-\
285faa354472"],

Cell[CellGroupData[{

Cell["(i) => (iv) ", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792593678079088*^9, 
  3.792593678673172*^9}, {3.793377057870475*^9, 3.7933770586643972`*^9}, {
  3.793379035762004*^9, 3.7933790413824787`*^9}, {3.793379143533257*^9, 
  3.793379149392561*^9}, {3.794749201623622*^9, 
  3.794749221256674*^9}},ExpressionUUID->"6ecaeca0-eb5b-40cd-b8bb-\
93384418f2d5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "c", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "c", "]"}], "**", 
            RowBox[{"adj", "[", "b", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "aa", "]"}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592848262369*^9, 3.792592848432878*^9}, {3.792593646239861*^9, 
   3.792593650802047*^9}, {3.792593684809256*^9, 3.792593725101365*^9}, {
   3.7925968365712433`*^9, 3.792596836948386*^9}, 3.79301715556467*^9, {
   3.793377061941378*^9, 3.793377095543686*^9}, {3.793377133715619*^9, 
   3.79337713760585*^9}, {3.7933772115422792`*^9, 3.793377212001401*^9}, {
   3.793378661273677*^9, 3.7933786981995697`*^9}, {3.79337882470848*^9, 
   3.793378845675589*^9}, {3.793379045712237*^9, 3.7933790528304*^9}, {
   3.793380273028878*^9, 3.793380273175949*^9}, {3.794749246258802*^9, 
   3.79474926761779*^9}, {3.795345448772156*^9, 3.795345457619553*^9}, {
   3.795857572508264*^9, 3.7958575807909307`*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"8206e235-e000-46f3-be1c-773ce7ca8657"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond4", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958575866015873`*^9, 3.7958575959310093`*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"9fc7b59c-b52d-44f6-861f-a98f3c633564"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.795858574799411*^9, 3.7958585834299917`*^9}, {
   3.7958586183194723`*^9, 3.7958586430882177`*^9}, 3.795858750803278*^9, 
   3.7958590211285133`*^9, 3.795859156203507*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"946304e9-7472-4ed2-bb2e-b0e71cf81579"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(iv) => (i) ", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
   3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792597173457746*^9, 
   3.792597202481496*^9}, {3.793017136785963*^9, 3.793017139583473*^9}, {
   3.7930181970472603`*^9, 3.793018210304758*^9}, 
   3.7947492246224747`*^9},ExpressionUUID->"c00e522b-ef52-445e-8cec-\
edbe07d01c8b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "v"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c"}], "-", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "w", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "v", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{"aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c"}], "-", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], ",", "1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", "aa"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "w", "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", 
           RowBox[{"adj", "[", "v", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", 
          RowBox[{"adj", "[", "v", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "v", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
         ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "v", "]"}], "**", 
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
          "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
           
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "v"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", "v"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", 
          RowBox[{"adj", "[", "w", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", 
           RowBox[{"adj", "[", "w", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c", "**", "cc", "**", "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb"}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc", "**", "w"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "b", "**", "c"}], "-", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "w", "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "v", "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7958577019111633`*^9, 3.7958577123613358`*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"86b67f2a-e381-4162-8e72-073be0e77990"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.7958577142970057`*^9, 3.795857732234149*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"f96e2d9d-2205-402a-a116-18cd35b946ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.795858646000018*^9, 3.795858750967551*^9, 
  3.795859021408532*^9, 3.795859156382861*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"e5ec5277-8906-4192-affd-5bac18751b63"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) <=> (v)", "Subsection",
 CellChangeTimes->{{3.794749229223976*^9, 
  3.794749232966704*^9}},ExpressionUUID->"5c0f55d7-c4fc-48c3-94f3-\
7bbd8aba482f"],

Cell[CellGroupData[{

Cell["(i) => (v)", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
  3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792593678079088*^9, 
  3.792593678673172*^9}, {3.793377057870475*^9, 3.7933770586643972`*^9}, {
  3.793379035762004*^9, 3.7933790413824787`*^9}, {3.793379143533257*^9, 
  3.793379149392561*^9}, {3.794749201623622*^9, 3.794749202884654*^9}, {
  3.794749239771381*^9, 
  3.794749243026351*^9}},ExpressionUUID->"3f6e02cf-6cb5-4376-b782-\
cdbebdf2a7d5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
      "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
       "a", "**", "b", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}],
       "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", 
          "aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"aa", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "a", "]"}], ",", 
         RowBox[{
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}], 
          "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "b", "**", "c"}]}], "+", 
          RowBox[{
          "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**",
            "a", "**", "b", "**", "c"}]}], ",", "cc"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", 
           "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "cc"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "bb", "**", "aa"}]}], "+", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
           "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
          "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{"cc", "**", "bb", "**", "aa", "**", "a"}]}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.77504463606568*^9, 3.775044670297163*^9}, {
   3.775044775875046*^9, 3.775044820950074*^9}, {3.775672344559834*^9, 
   3.7756723817423553`*^9}, {3.775672582243185*^9, 3.7756725861061563`*^9}, {
   3.775676939491886*^9, 3.77567694237218*^9}, {3.775676973429263*^9, 
   3.77567697409936*^9}, {3.775677007167787*^9, 3.77567700726886*^9}, {
   3.782541347861659*^9, 3.782541348280438*^9}, {3.782557584324613*^9, 
   3.782557594521274*^9}, {3.782559309624772*^9, 3.782559322586474*^9}, {
   3.782559451770254*^9, 3.7825594535535183`*^9}, {3.7825595559279757`*^9, 
   3.7825595694176607`*^9}, {3.7825596660230217`*^9, 3.782559666247205*^9}, {
   3.7825606647236147`*^9, 3.7825606913432283`*^9}, 3.7837117784653883`*^9, {
   3.783830048876854*^9, 3.783830048929653*^9}, {3.784007069127306*^9, 
   3.784007072582987*^9}, 3.784354199484157*^9, {3.78435423688941*^9, 
   3.784354237025569*^9}, {3.792592139626618*^9, 3.7925921757518187`*^9}, {
   3.792592848262369*^9, 3.792592848432878*^9}, {3.792593646239861*^9, 
   3.792593650802047*^9}, {3.792593684809256*^9, 3.792593725101365*^9}, {
   3.7925968365712433`*^9, 3.792596836948386*^9}, 3.79301715556467*^9, {
   3.793377061941378*^9, 3.793377095543686*^9}, {3.793377133715619*^9, 
   3.79337713760585*^9}, {3.7933772115422792`*^9, 3.793377212001401*^9}, {
   3.793378661273677*^9, 3.7933786981995697`*^9}, {3.79337882470848*^9, 
   3.793378845675589*^9}, {3.793379045712237*^9, 3.7933790528304*^9}, {
   3.793380273028878*^9, 3.793380273175949*^9}, {3.794749451760043*^9, 
   3.7947494773264914`*^9}, {3.795345467991373*^9, 3.795345473332584*^9}, {
   3.7958577529032307`*^9, 3.795857761350175*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"64999b28-4eac-41bc-8e13-5d58625b27eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond5", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857787388721*^9, 3.7958577975450287`*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"79f90cc7-d94f-4a4b-92bc-c0df8e0f929a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.795858650484893*^9, 3.795858751123315*^9, 
  3.795859021500874*^9, 3.7958591564291058`*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"57922607-30d8-44bb-ae84-5861562fd2a8"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(v) => (i)", "Subsubsection",
 CellChangeTimes->{{3.784354891310275*^9, 3.784354891927288*^9}, {
   3.7925921344987917`*^9, 3.7925921382569304`*^9}, {3.792597173457746*^9, 
   3.792597202481496*^9}, {3.793017136785963*^9, 3.793017139583473*^9}, 
   3.793018066162611*^9, 
   3.794749237824669*^9},ExpressionUUID->"9521a127-2c87-4f9e-9ff8-\
6635a3d098a8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
      RowBox[{
      "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "aa", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "**", "aa"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "c", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"adj", "[", "cc", "]"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"cc", "**", "c"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}], "**", 
        RowBox[{"adj", "[", "b", "]"}], "**", 
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", "**",
        "aa", "**", "a"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"adj", "[", "a", "]"}], "**", 
        RowBox[{"adj", "[", "aa", "]"}], "**", 
        RowBox[{"adj", "[", "bb", "]"}], "**", 
        RowBox[{"adj", "[", "cc", "]"}], "**", 
        RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
        "c", "**", "cc", "**", "c", "**", 
       RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{"-", "aa"}], "+", 
      RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"a", "**", "aa"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], "+", 
      RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
     RowBox[{
      RowBox[{"-", "cc"}], "+", 
      RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"cc", "**", "c"}]}], "+", 
      RowBox[{
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
       "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
        "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{
      "aa", "**", "a", "**", "b", "**", "c", "**", "cc", "**", "c", "**", 
       "cc", "**", "bb", "**", "aa", "**", "a", "**", "aa", "**", "a", "**", 
       "b", "**", "c", "**", "cc", "**", "c", "**", "cc", "**", "bb", "**", 
       "aa", "**", "a"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
        "b", "**", "c", "**", "cc"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], "+", 
      RowBox[{"c", "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}], "-", 
      RowBox[{
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}], "**", 
       RowBox[{"adj", "[", "c", "]"}], "**", 
       RowBox[{"adj", "[", "b", "]"}], "**", 
       RowBox[{"adj", "[", "a", "]"}], "**", 
       RowBox[{"adj", "[", "aa", "]"}], "**", 
       RowBox[{"adj", "[", "bb", "]"}], "**", 
       RowBox[{"adj", "[", "cc", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"certificate", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "s", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{
         RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**", 
          "cc", "**", "bb", "**", "aa"}]}], ",", "1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", "aa"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "aa", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", 
          "aa"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa"}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
           "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**",
           "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{
         "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", "a", "**", 
          "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", 
           "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", 
           "b"}]}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "bb", "**", "aa",
           "**", "a", "**", "b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
         "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"adj", "[", "a", "]"}], "**", 
            RowBox[{"adj", "[", "aa", "]"}], "**", 
            RowBox[{"adj", "[", "bb", "]"}], "**", 
            RowBox[{"adj", "[", "cc", "]"}], "**", 
            RowBox[{"adj", "[", "c", "]"}]}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
            "c", "**", "cc", "**", "c", "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{"adj", "[", "cc", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
           "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "c"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b"}], 
         ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "u", "]"}], "**", "aa", "**", "a", "**", "b", "**",
           "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "cc", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"cc", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "**", "cc", "**", "bb", "**", "aa", "**", "a"}]}], 
          "+", 
          RowBox[{"c", "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", "u"}]}], ",", 
         RowBox[{"b", "**", "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc"}], ",", 
         RowBox[{
          RowBox[{"-", "c"}], "+", 
          RowBox[{"c", "**", "cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"cc", "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", "cc", "**", "c"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"cc", "**", "c"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "cc"}], "+", 
          RowBox[{"cc", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", "a", "**", "b", "**", "c"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "s", "]"}], "**", "c"}]}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", "c"}], ",", 
         RowBox[{
          RowBox[{"cc", "**", "bb", "**", "aa"}], "-", 
          RowBox[{
          "cc", "**", "bb", "**", "aa", "**", "a", "**", "b", "**", "c", "**",
            "cc", "**", "bb", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"adj", "[", "c", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
         "a", "**", "b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", 
           "bb"}]}], ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb"}],
          ",", 
         RowBox[{
          RowBox[{"-", "aa"}], "+", 
          RowBox[{"aa", "**", "a", "**", "aa"}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adj", "[", "c", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "s", "]"}], "**", "c", "**", "cc", "**", "bb", 
           "**", "aa", "**", "a"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", "a"}]}], ",", 
         RowBox[{"aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{"a", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "a", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", 
          RowBox[{"adj", "[", "aa", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", "s"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "aa", "**", "a", "**",
            "b", "**", "c", "**", "cc"}]}], ",", 
         RowBox[{"bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "bb", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a", "**", "aa"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "aa", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}], "**", 
           RowBox[{"adj", "[", "aa", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "b", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"a", "**", "aa"}], "-", 
          RowBox[{
           RowBox[{"adj", "[", "aa", "]"}], "**", 
           RowBox[{"adj", "[", "a", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "aa", "]"}], "**", 
          RowBox[{"adj", "[", "bb", "]"}], "**", 
          RowBox[{"adj", "[", "cc", "]"}], "**", 
          RowBox[{"adj", "[", "c", "]"}], "**", "s", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"adj", "[", "c", "]"}], "**", 
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          RowBox[{"a", "**", "aa", "**", "a"}]}], ",", 
         RowBox[{"b", "**", "c", "**", "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"adj", "[", "c", "]"}]}], "+", 
          RowBox[{
           RowBox[{"adj", "[", "c", "]"}], "**", 
           RowBox[{"adj", "[", "cc", "]"}], "**", 
           RowBox[{"adj", "[", "c", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"adj", "[", "b", "]"}], "**", 
          RowBox[{"adj", "[", "a", "]"}], "**", "a", "**", "b", "**", "c", "**",
           "cc", "**", "bb", "**", "aa", "**", 
          RowBox[{"adj", "[", "aa", "]"}], "**", "u", "**", "b", "**", 
          "c"}]}], "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.795857815483152*^9, 3.7958578280733967`*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"bfcc6989-6726-4084-8bbf-ddf525e4b156"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckCertificates", "[", 
  RowBox[{"certificate", ",", "cond1", ",", "assumptions"}], "]"}]], "Input",
 CellChangeTimes->{{3.795857829483135*^9, 3.795857842394631*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"78ed49f4-0ab2-4eaa-9631-112003984719"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{
  3.795858653091474*^9, 3.795858751290042*^9, {3.795859021671336*^9, 
   3.795859046370873*^9}, 3.795859156615198*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"602c7ec2-2cef-4b8b-9a8a-5f0e7a2dfe2b"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 2.9", "Section",
 CellChangeTimes->{{3.7958675214634943`*^9, 3.795867526865468*^9}, {
  3.795867633860669*^9, 
  3.795867634000492*^9}},ExpressionUUID->"8b0935d0-2065-4edc-b891-\
3d7d95f6c634"],

Cell["\<\
To prove Theorem 2.9, the computations of Theorems 2.1, 2.3, 2.4 and 2.6 can \
be adopted.\
\>", "Text",
 CellChangeTimes->{{3.795867531798132*^9, 3.795867542341692*^9}, {
   3.795867576174984*^9, 3.795867654468843*^9}, 3.795867866890867*^9, {
   3.795874675034639*^9, 
   3.795874682717368*^9}},ExpressionUUID->"7257ae89-312f-4395-a9f4-\
3739068f2708"]
}, Closed]]
},
WindowSize->{814, 940},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>1.5 Inherited,
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 502, 9, 122, "Text",ExpressionUUID->"19bfce8d-5d1a-4675-bcd1-549558972b6f"],
Cell[1063, 31, 10411, 260, 2125, "Input",ExpressionUUID->"0fff3040-e0ab-44c0-90a8-d7cd47c0acd3"],
Cell[11477, 293, 1985, 52, 295, "Input",ExpressionUUID->"c7743e31-7f95-464d-a4a6-a03fddca5283"],
Cell[CellGroupData[{
Cell[13487, 349, 501, 7, 101, "Section",ExpressionUUID->"c53124fd-2698-4e18-93b7-5335e65534bf"],
Cell[13991, 358, 5096, 155, 302, "Text",ExpressionUUID->"1c35aff3-ce4b-4e36-8424-fc8afe9c5b38"],
Cell[19090, 515, 5203, 117, 419, "Input",ExpressionUUID->"10c5bc42-10aa-488c-acb3-c05b58398d1f"],
Cell[CellGroupData[{
Cell[24318, 636, 438, 7, 81, "Subsection",ExpressionUUID->"b2abbb50-1000-4948-9fb3-beffaf4e5968"],
Cell[CellGroupData[{
Cell[24781, 647, 161, 3, 67, "Subsubsection",ExpressionUUID->"e5d52d4e-a3f7-4abd-945b-31585cc8c102"],
Cell[24945, 652, 46883, 1195, 2434, "Input",ExpressionUUID->"8c2e9927-ff5e-4039-9251-6f4ecd63ce6b"],
Cell[CellGroupData[{
Cell[71853, 1851, 470, 7, 46, "Input",ExpressionUUID->"bf7c4f65-ca79-445b-b5ba-d223a60db01c"],
Cell[72326, 1860, 782, 12, 52, "Output",ExpressionUUID->"e7ecc410-cc9f-4a50-a395-015a22f5e8bd"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[73157, 1878, 212, 4, 53, "Subsubsection",ExpressionUUID->"f67bda2c-d6ce-45c7-b094-b67a26ad81e3"],
Cell[73372, 1884, 131114, 3177, 8355, "Input",ExpressionUUID->"0a99a2af-4b18-4343-a20b-1879c4be6941"],
Cell[CellGroupData[{
Cell[204511, 5065, 321, 5, 46, "Input",ExpressionUUID->"4f755188-b921-4837-93e4-fdb6d32cb7d3"],
Cell[204835, 5072, 420, 7, 52, "Output",ExpressionUUID->"3c8bf2e7-73c6-42cf-bb1f-46d23ff08ad3"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[205316, 5086, 477, 7, 55, "Subsection",ExpressionUUID->"8c7216d5-e985-4f7d-81fc-88fca283d9c7"],
Cell[CellGroupData[{
Cell[205818, 5097, 293, 5, 67, "Subsubsection",ExpressionUUID->"10b859a2-3734-4fe9-88d6-8c126d4eccbc"],
Cell[206114, 5104, 254, 4, 46, "Input",ExpressionUUID->"703e998e-0fa4-4e0d-a994-e49417dc6d22"]
}, Closed]],
Cell[CellGroupData[{
Cell[206405, 5113, 265, 4, 53, "Subsubsection",ExpressionUUID->"9ea1b0ff-43c6-49a7-9168-8f06a4e3a7f3"],
Cell[206673, 5119, 128951, 3182, 7580, "Input",ExpressionUUID->"05f0a2d9-447c-4f01-b7b5-6efe449d8291"],
Cell[CellGroupData[{
Cell[335649, 8305, 325, 5, 46, "Input",ExpressionUUID->"e43b8d15-14b6-45cf-b686-aaa14fa75b86"],
Cell[335977, 8312, 569, 9, 52, "Output",ExpressionUUID->"a5e8735d-d216-4880-bf7a-ea48df1d1030"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[336607, 8328, 285, 5, 55, "Subsection",ExpressionUUID->"70a1a771-414a-46ce-be6c-ff476e44d458"],
Cell[CellGroupData[{
Cell[336917, 8337, 159, 3, 67, "Subsubsection",ExpressionUUID->"127ea162-3f30-41a1-9b5e-1fa386e2165a"],
Cell[337079, 8342, 40700, 1064, 2217, "Input",ExpressionUUID->"29503700-ed5e-4648-a4ef-d2d5698f7452"],
Cell[CellGroupData[{
Cell[377804, 9410, 371, 6, 46, "Input",ExpressionUUID->"5445cb18-1ef2-4e92-99d8-70c02f365bf1"],
Cell[378178, 9418, 505, 9, 52, "Output",ExpressionUUID->"fe894f60-0548-4247-9a34-f3819a45afe0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[378732, 9433, 208, 4, 53, "Subsubsection",ExpressionUUID->"829806b2-b48b-45ab-ac70-20bef5755a01"],
Cell[378943, 9439, 30442, 800, 1783, "Input",ExpressionUUID->"4a9907d0-25e2-44c1-8930-5d48d803f745"],
Cell[CellGroupData[{
Cell[409410, 10243, 324, 5, 46, "Input",ExpressionUUID->"d0e63c92-88b6-4913-b941-879d79563a56"],
Cell[409737, 10250, 489, 8, 52, "Output",ExpressionUUID->"c3353d47-73e7-41f8-b9d9-5679e452fa8e"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[410287, 10265, 563, 9, 55, "Subsection",ExpressionUUID->"e3cf514f-f24a-44c6-9ba7-9f00f5096584"],
Cell[CellGroupData[{
Cell[410875, 10278, 163, 3, 67, "Subsubsection",ExpressionUUID->"7269dd26-e454-42f5-a233-722381e39c2b"],
Cell[411041, 10283, 50069, 1260, 2589, "Input",ExpressionUUID->"74f78d69-a899-4268-b263-d405244ce8a6"],
Cell[CellGroupData[{
Cell[461135, 11547, 325, 5, 46, "Input",ExpressionUUID->"e7736374-9f51-44b6-9725-7b9cfaf2a3b0"],
Cell[461463, 11554, 486, 9, 52, "Output",ExpressionUUID->"cf1dbbd9-ae59-4859-9d69-1564c95d6786"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[461998, 11569, 335, 5, 53, "Subsubsection",ExpressionUUID->"a18625ba-69f2-46f0-a982-759e6b6732d5"],
Cell[462336, 11576, 127192, 3093, 7487, "Input",ExpressionUUID->"df669f95-3961-489c-bbde-1502337074c3"],
Cell[CellGroupData[{
Cell[589553, 14673, 323, 5, 46, "Input",ExpressionUUID->"a0bb2937-13ac-481f-beb6-a8686c550949"],
Cell[589879, 14680, 325, 6, 52, "Output",ExpressionUUID->"c42bb7aa-f4df-4f09-b921-9d490a0c8bb5"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[590277, 14694, 158, 3, 78, "Section",ExpressionUUID->"be0135d7-2748-461a-9c4e-92203a621a32"],
Cell[590438, 14699, 268, 6, 88, "Text",ExpressionUUID->"f987594c-1fc6-4920-88ed-69eba683cae6"]
}, Closed]],
Cell[CellGroupData[{
Cell[590743, 14710, 644, 10, 78, "Section",ExpressionUUID->"49f384b4-2aaa-4c1f-8175-bd15fc442992"],
Cell[591390, 14722, 4560, 134, 303, "Text",ExpressionUUID->"9bcb1b39-c960-4351-9f24-905c25e4186f"],
Cell[595953, 14858, 3290, 92, 388, "Input",ExpressionUUID->"f15967c6-05a4-4d6b-860e-0eb7ccfada56"],
Cell[CellGroupData[{
Cell[599268, 14954, 259, 4, 81, "Subsection",ExpressionUUID->"4022dc23-ced1-437b-8048-71d8f5d3b3cb"],
Cell[CellGroupData[{
Cell[599552, 14962, 213, 4, 67, "Subsubsection",ExpressionUUID->"81383769-030d-4f09-9a8f-966a69df2197"],
Cell[599768, 14968, 26950, 688, 1349, "Input",ExpressionUUID->"399cac9c-0262-4499-a270-6d921f05d3ad"],
Cell[CellGroupData[{
Cell[626743, 15660, 322, 5, 46, "Input",ExpressionUUID->"cfc8e995-e9ed-47fb-9e2f-969507d8a16f"],
Cell[627068, 15667, 451, 7, 52, "Output",ExpressionUUID->"a2fcca71-d509-46dd-9949-dbd42dbb1937"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[627568, 15680, 162, 3, 53, "Subsubsection",ExpressionUUID->"a91147f0-32a8-4a0f-8b03-421110cdf2fe"],
Cell[627733, 15685, 218020, 5124, 12850, "Input",ExpressionUUID->"622ce238-8e97-4af6-8bf1-00c9ee098d4a"],
Cell[CellGroupData[{
Cell[845778, 20813, 324, 5, 46, "Input",ExpressionUUID->"0cc0c0ae-8f8a-4f57-8f36-c43b12672ede"],
Cell[846105, 20820, 448, 8, 52, "Output",ExpressionUUID->"b287c804-53b3-4c22-b120-1f62e8ccbe3d"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[846614, 20835, 508, 8, 55, "Subsection",ExpressionUUID->"efc6422c-1a6b-4189-8353-27bb74bf306b"],
Cell[CellGroupData[{
Cell[847147, 20847, 160, 3, 67, "Subsubsection",ExpressionUUID->"79e7460d-b32e-40a4-95ac-093be0bd472b"],
Cell[847310, 20852, 165230, 3973, 9502, "Input",ExpressionUUID->"07d3bccc-b058-43d5-bf58-b1c211fc4523"],
Cell[CellGroupData[{
Cell[1012565, 24829, 272, 4, 46, "Input",ExpressionUUID->"983a5a15-34bb-4cff-8ac5-7b77f3496052"],
Cell[1012840, 24835, 419, 7, 52, "Output",ExpressionUUID->"a94b5f74-e1ba-4da2-af29-13bfba00f2a6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1013308, 24848, 209, 4, 53, "Subsubsection",ExpressionUUID->"6b6c7d7d-b384-4483-8073-fb180245c2f2"],
Cell[1013520, 24854, 35807, 897, 1876, "Input",ExpressionUUID->"52d6c720-6af1-4894-b893-29d6e7888d99"],
Cell[CellGroupData[{
Cell[1049352, 25755, 272, 4, 46, "Input",ExpressionUUID->"0bd239b0-344d-4c82-a8f3-b06020007c91"],
Cell[1049627, 25761, 415, 7, 52, "Output",ExpressionUUID->"d1a1a104-eb28-411e-a760-6b1e5955155c"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1050103, 25775, 357, 6, 55, "Subsection",ExpressionUUID->"e19130a1-a1b2-46f9-b705-dd2eb3599d53"],
Cell[CellGroupData[{
Cell[1050485, 25785, 162, 3, 67, "Subsubsection",ExpressionUUID->"6249339b-181a-4886-b631-d985455f33fc"],
Cell[1050650, 25790, 25538, 668, 1380, "Input",ExpressionUUID->"8f319ecc-da3f-4d63-b937-fe88b87bd2ad"],
Cell[CellGroupData[{
Cell[1076213, 26462, 276, 4, 46, "Input",ExpressionUUID->"1692d2b3-f3d5-4f20-a0bf-6f2f950c5e6e"],
Cell[1076492, 26468, 409, 7, 52, "Output",ExpressionUUID->"acb39251-af76-442f-a9d8-18e0953dc8f7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1076950, 26481, 164, 3, 53, "Subsubsection",ExpressionUUID->"fa2917f0-e162-4662-9697-38f2d5f2c74b"],
Cell[1077117, 26486, 205715, 4903, 12230, "Input",ExpressionUUID->"33d98fd3-3f17-4d8e-9ea5-3f5f9015506c"],
Cell[CellGroupData[{
Cell[1282857, 31393, 274, 4, 46, "Input",ExpressionUUID->"9d5a76cb-d638-4c91-afb8-e279e5006406"],
Cell[1283134, 31399, 415, 7, 52, "Output",ExpressionUUID->"9045f67d-1beb-4ed2-9985-8b15fbe57393"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1283622, 31414, 692, 10, 78, "Section",ExpressionUUID->"3df7a30e-0932-4e2d-8c4c-5c4d2b848f94"],
Cell[1284317, 31426, 4832, 142, 303, "Text",ExpressionUUID->"bec067b7-08e2-43f5-9697-b12aa3d7fa54"],
Cell[1289152, 31570, 3699, 96, 419, "Input",ExpressionUUID->"ac2bf4c8-79be-45cf-a188-5c31a5972056"],
Cell[CellGroupData[{
Cell[1292876, 31670, 259, 4, 81, "Subsection",ExpressionUUID->"edd6014c-8bd6-4abe-ab4c-715b5fdeea3e"],
Cell[CellGroupData[{
Cell[1293160, 31678, 213, 4, 67, "Subsubsection",ExpressionUUID->"908fe205-d6bd-4620-87d7-86a403e0056b"],
Cell[1293376, 31684, 23043, 594, 1194, "Input",ExpressionUUID->"f2d41813-3c25-482e-80d7-a42da0950702"],
Cell[CellGroupData[{
Cell[1316444, 32282, 272, 4, 46, "Input",ExpressionUUID->"8d7cca1b-d5db-4413-813a-52d9d27bef05"],
Cell[1316719, 32288, 332, 6, 52, "Output",ExpressionUUID->"d3780a28-4e3d-4060-8415-d884def8c576"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1317100, 32300, 162, 3, 53, "Subsubsection",ExpressionUUID->"5662439b-b011-43e8-943f-36fe9c0656fb"],
Cell[1317265, 32305, 232303, 5626, 13532, "Input",ExpressionUUID->"53f4e43f-4099-48c9-a858-4f98c629bb53"],
Cell[CellGroupData[{
Cell[1549593, 37935, 274, 4, 46, "Input",ExpressionUUID->"440f7f67-43da-4e28-97ce-04993ae4d929"],
Cell[1549870, 37941, 349, 6, 52, "Output",ExpressionUUID->"e2a664c6-d0d7-4b70-aa5e-d8f6d44a10a0"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1550280, 37954, 508, 8, 55, "Subsection",ExpressionUUID->"255d8eb6-5515-4c27-b044-4ad14f2eaea9"],
Cell[CellGroupData[{
Cell[1550813, 37966, 160, 3, 67, "Subsubsection",ExpressionUUID->"5fef906c-9413-479b-a394-ed65d2113794"],
Cell[1550976, 37971, 156375, 3937, 8789, "Input",ExpressionUUID->"3acebea7-237f-4086-b27e-646bcf3ba85a"],
Cell[CellGroupData[{
Cell[1707376, 41912, 274, 4, 46, "Input",ExpressionUUID->"caf679f0-e078-46e5-a81a-1acb9b3799b2"],
Cell[1707653, 41918, 345, 6, 52, "Output",ExpressionUUID->"da7e9861-31cd-4017-bb26-c9495a5632ea"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1708047, 41930, 209, 4, 53, "Subsubsection",ExpressionUUID->"f3c223f0-a31d-4d02-a9d3-6e1458a600f9"],
Cell[1708259, 41936, 32021, 806, 1721, "Input",ExpressionUUID->"a27b02fc-aa71-445f-bfc9-c76117427291"],
Cell[CellGroupData[{
Cell[1740305, 42746, 272, 4, 46, "Input",ExpressionUUID->"ff6d904a-fdf3-4b08-b533-ac3582fd5897"],
Cell[1740580, 42752, 347, 6, 52, "Output",ExpressionUUID->"1dc6c1c4-ab4d-473c-a156-87fdb8251583"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1740988, 42765, 357, 6, 55, "Subsection",ExpressionUUID->"f9586a57-ef53-48f0-b2a0-fc3458476bfe"],
Cell[CellGroupData[{
Cell[1741370, 42775, 162, 3, 67, "Subsubsection",ExpressionUUID->"ad4c1520-311d-4c7d-a421-a49e851fccef"],
Cell[1741535, 42780, 21726, 575, 1225, "Input",ExpressionUUID->"6420aa15-3e06-477a-94a3-83bd138e373b"],
Cell[CellGroupData[{
Cell[1763286, 43359, 323, 5, 46, "Input",ExpressionUUID->"140ec08d-7141-4236-b602-fe69ff17aa3d"],
Cell[1763612, 43366, 334, 6, 52, "Output",ExpressionUUID->"44278999-bada-4ded-ac1f-9f5a873eb245"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1763995, 43378, 164, 3, 53, "Subsubsection",ExpressionUUID->"78d4b843-615f-4748-b17c-cec0a13260ae"],
Cell[1764162, 43383, 197643, 4803, 11486, "Input",ExpressionUUID->"738b4004-31fa-49cc-bb4a-f3d10406cdfd"],
Cell[CellGroupData[{
Cell[1961830, 48190, 276, 4, 46, "Input",ExpressionUUID->"fd31c68f-e878-4bb6-b0a6-3826b239a90b"],
Cell[1962109, 48196, 345, 6, 52, "Output",ExpressionUUID->"eca4cf7e-c889-4350-ae6f-a5adcd2a21c3"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1962527, 48210, 673, 10, 78, "Section",ExpressionUUID->"e2fc71b6-f8f2-499b-b2a9-2ecd2380fc5c"],
Cell[1963203, 48222, 3599, 104, 232, "Text",ExpressionUUID->"84ae6721-a346-4f93-8863-f8d044a2d300"],
Cell[1966805, 48328, 2874, 75, 295, "Input",ExpressionUUID->"75c1efc3-5a5c-47a4-9e4f-88ad07da0c6e"],
Cell[CellGroupData[{
Cell[1969704, 48407, 536, 9, 81, "Subsection",ExpressionUUID->"4d49a244-dc14-4153-b4d7-28d0f4996ed1"],
Cell[CellGroupData[{
Cell[1970265, 48420, 166, 3, 67, "Subsubsection",ExpressionUUID->"837d1d9f-935b-49f6-b7e2-196c10fa5186"],
Cell[1970434, 48425, 21520, 563, 1194, "Input",ExpressionUUID->"1fbd5cfe-6788-4b24-9494-ffb0a088d469"],
Cell[CellGroupData[{
Cell[1991979, 48992, 278, 5, 46, "Input",ExpressionUUID->"089fb0da-5886-4848-85ca-aeb04ea93366"],
Cell[1992260, 48999, 337, 7, 52, "Output",ExpressionUUID->"b8787efb-b19c-4adc-b7c1-3c8c4d8c6eda"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1992646, 49012, 215, 4, 53, "Subsubsection",ExpressionUUID->"52a1f6d6-65ad-40db-9fc6-7f59a29116c2"],
Cell[1992864, 49018, 122435, 3010, 6867, "Input",ExpressionUUID->"6241b1be-f6ee-41cb-b0df-b8317b25cd44"],
Cell[CellGroupData[{
Cell[2115324, 52032, 302, 6, 46, "Input",ExpressionUUID->"e843e1b3-2cfb-424d-9c8e-db7c0f16d40f"],
Cell[2115629, 52040, 378, 8, 52, "Output",ExpressionUUID->"00db6c6c-e994-42f5-886d-c81b3ef894f1"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2116068, 52055, 584, 9, 55, "Subsection",ExpressionUUID->"643a5cde-bdf5-4284-b958-f2a355cab662"],
Cell[CellGroupData[{
Cell[2116677, 52068, 217, 4, 67, "Subsubsection",ExpressionUUID->"ef2ed039-6b29-40f6-be0b-8ad4be6c798a"],
Cell[2116897, 52074, 26043, 684, 1380, "Input",ExpressionUUID->"437ae619-60f7-483c-97ef-b644f1faf80a"],
Cell[CellGroupData[{
Cell[2142965, 52762, 276, 5, 46, "Input",ExpressionUUID->"f1106bf2-21d5-49a9-8172-3a51b6304c42"],
Cell[2143244, 52769, 316, 7, 52, "Output",ExpressionUUID->"cbf82826-7b95-45fe-844e-a538840f4f36"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2143609, 52782, 263, 4, 53, "Subsubsection",ExpressionUUID->"a40fae15-4892-4fac-a9c5-86ffb6c2730d"],
Cell[2143875, 52788, 115166, 2806, 6557, "Input",ExpressionUUID->"941ee578-2982-4434-8a44-46d60e519726"],
Cell[CellGroupData[{
Cell[2259066, 55598, 278, 5, 46, "Input",ExpressionUUID->"3d450d78-96dd-44fd-a692-130a905b94f3"],
Cell[2259347, 55605, 326, 7, 52, "Output",ExpressionUUID->"16a0967d-c5c7-497c-b423-f0a8e68e282e"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2259746, 55620, 826, 12, 78, "Section",ExpressionUUID->"0c6a2b2d-b9d6-411d-a5bd-0117f78fcb33"],
Cell[2260575, 55634, 6072, 179, 337, "Text",ExpressionUUID->"b8e9d454-c1bc-41b2-a7bd-234f970aebbf"],
Cell[2266650, 55815, 3730, 102, 450, "Input",ExpressionUUID->"bbe0e934-a1c4-4c60-91b4-d41dd3ac54d6"],
Cell[CellGroupData[{
Cell[2270405, 55921, 160, 3, 81, "Subsection",ExpressionUUID->"2af7b074-380b-4e85-93ed-ef55dcce24f7"],
Cell[CellGroupData[{
Cell[2270590, 55928, 361, 6, 67, "Subsubsection",ExpressionUUID->"f40c0657-670c-4e6e-b93e-639e8cd6e6e2"],
Cell[2270954, 55936, 23131, 592, 1318, "Input",ExpressionUUID->"8380b620-8f29-49b5-b288-7876484712bc"],
Cell[CellGroupData[{
Cell[2294110, 56532, 276, 5, 46, "Input",ExpressionUUID->"b7299426-ab3e-4871-88da-e6af9be32e0e"],
Cell[2294389, 56539, 331, 7, 52, "Output",ExpressionUUID->"0858501f-e199-4fce-8dc2-1a33d35c978f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2294769, 56552, 261, 4, 53, "Subsubsection",ExpressionUUID->"dc8a3cda-f717-4af1-a31e-d7eb837efb24"],
Cell[2295033, 56558, 64800, 1638, 3643, "Input",ExpressionUUID->"19112fc8-7c49-4431-ae2e-ad64d1805bd0"],
Cell[CellGroupData[{
Cell[2359858, 58200, 276, 5, 46, "Input",ExpressionUUID->"d975d93f-5a0e-4d23-94a4-78904c1140d5"],
Cell[2360137, 58207, 300, 6, 52, "Output",ExpressionUUID->"786fa198-ee57-4fa8-8f85-a86e1a454608"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2360498, 58220, 312, 5, 55, "Subsection",ExpressionUUID->"c71deb49-a3c5-4b3f-92b7-8ceb54ff4391"],
Cell[CellGroupData[{
Cell[2360835, 58229, 291, 5, 67, "Subsubsection",ExpressionUUID->"dfd1d489-17cd-4522-9a4f-2c84bcf66ab4"],
Cell[2361129, 58236, 410, 7, 46, "Input",ExpressionUUID->"23624354-ffe0-44ba-814b-b0989e4ab416"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2361576, 58248, 342, 5, 67, "Subsubsection",ExpressionUUID->"8e5024df-e4ec-4657-93a3-282dee39ecf1"],
Cell[2361921, 58255, 81679, 2030, 4976, "Input",ExpressionUUID->"ad742d80-5b4b-43bf-9496-f9bda0c65562"],
Cell[CellGroupData[{
Cell[2443625, 60289, 328, 6, 46, "Input",ExpressionUUID->"157b99dc-ce60-4163-a834-cee7b7aa3b2b"],
Cell[2443956, 60297, 330, 6, 52, "Output",ExpressionUUID->"073baf88-c514-40db-93ba-fed23c0a9505"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2444347, 60310, 162, 3, 55, "Subsection",ExpressionUUID->"28e87859-37dc-4f1c-bda7-285faa354472"],
Cell[CellGroupData[{
Cell[2444534, 60317, 459, 7, 67, "Subsubsection",ExpressionUUID->"6ecaeca0-eb5b-40cd-b8bb-93384418f2d5"],
Cell[2444996, 60326, 19506, 489, 1039, "Input",ExpressionUUID->"8206e235-e000-46f3-be1c-773ce7ca8657"],
Cell[CellGroupData[{
Cell[2464527, 60819, 280, 5, 46, "Input",ExpressionUUID->"9fc7b59c-b52d-44f6-861f-a98f3c633564"],
Cell[2464810, 60826, 369, 7, 52, "Output",ExpressionUUID->"946304e9-7472-4ed2-bb2e-b0e71cf81579"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2465228, 60839, 390, 6, 53, "Subsubsection",ExpressionUUID->"c00e522b-ef52-445e-8cec-edbe07d01c8b"],
Cell[2465621, 60847, 116648, 2773, 7115, "Input",ExpressionUUID->"86b67f2a-e381-4162-8e72-073be0e77990"],
Cell[CellGroupData[{
Cell[2582294, 63624, 278, 5, 46, "Input",ExpressionUUID->"f96e2d9d-2205-402a-a116-18cd35b946ac"],
Cell[2582575, 63631, 299, 6, 52, "Output",ExpressionUUID->"e5ec5277-8906-4192-affd-5bac18751b63"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2582935, 63644, 159, 3, 55, "Subsection",ExpressionUUID->"5c0f55d7-c4fc-48c3-94f3-7bbd8aba482f"],
Cell[CellGroupData[{
Cell[2583119, 63651, 506, 8, 67, "Subsubsection",ExpressionUUID->"3f6e02cf-6cb5-4376-b782-cdbebdf2a7d5"],
Cell[2583628, 63661, 18220, 461, 1008, "Input",ExpressionUUID->"64999b28-4eac-41bc-8e13-5d58625b27eb"],
Cell[CellGroupData[{
Cell[2601873, 64126, 278, 5, 46, "Input",ExpressionUUID->"79f90cc7-d94f-4a4b-92bc-c0df8e0f929a"],
Cell[2602154, 64133, 288, 6, 52, "Output",ExpressionUUID->"57922607-30d8-44bb-ae84-5861562fd2a8"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2602491, 64145, 360, 6, 53, "Subsubsection",ExpressionUUID->"9521a127-2c87-4f9e-9ff8-6635a3d098a8"],
Cell[2602854, 64153, 109982, 2768, 5968, "Input",ExpressionUUID->"bfcc6989-6726-4084-8bbf-ddf525e4b156"],
Cell[CellGroupData[{
Cell[2712861, 66925, 276, 5, 46, "Input",ExpressionUUID->"78ed49f4-0ab2-4eaa-9631-112003984719"],
Cell[2713140, 66932, 327, 7, 52, "Output",ExpressionUUID->"602c7ec2-2cef-4b8b-9a8a-5f0e7a2dfe2b"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2713540, 66947, 207, 4, 78, "Section",ExpressionUUID->"8b0935d0-2065-4edc-b891-3d7d95f6c634"],
Cell[2713750, 66953, 363, 8, 88, "Text",ExpressionUUID->"7257ae89-312f-4395-a9f4-3739068f2708"]
}, Closed]]
}
]
*)

